@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,8 +12,8 @@
 
 #pragma once
 
-#include <seqan3/std/iterator>
-#include <seqan3/std/ranges>
+#include <iterator>
+#include <ranges>
 
 #include <seqan3/alignment/configuration/align_config_band.hpp>
 #include <seqan3/alignment/matrix/detail/alignment_matrix_column_major_range_base.hpp>
@@ -61,31 +61,31 @@ private:
     //!\brief The base class for data storage.
     using matrix_base_t = alignment_trace_matrix_base<trace_t>;
     //!\brief The base class for iterating over the matrix.
-    using range_base_t = alignment_matrix_column_major_range_base<alignment_trace_matrix_full_banded<trace_t,
-                                                                                                coordinate_only>>;
+    using range_base_t =
+        alignment_matrix_column_major_range_base<alignment_trace_matrix_full_banded<trace_t, coordinate_only>>;
     //!\brief Befriend the range base class.
     friend range_base_t;
 
 protected:
-    using typename matrix_base_t::element_type;
     using typename matrix_base_t::coordinate_type;
+    using typename matrix_base_t::element_type;
     using typename range_base_t::alignment_column_type;
     //!\copydoc alignment_matrix_column_major_range_base::column_data_view_type
-    using column_data_view_type = std::conditional_t<coordinate_only,
-                                        decltype(std::views::iota(coordinate_type{}, coordinate_type{})),
-                                        decltype(views::zip(std::declval<std::span<element_type>>(),
-                                                                std::declval<std::span<element_type>>(),
-                                                                std::views::iota(coordinate_type{}, coordinate_type{})))>;
+    using column_data_view_type =
+        std::conditional_t<coordinate_only,
+                           decltype(std::views::iota(coordinate_type{}, coordinate_type{})),
+                           decltype(views::zip(std::declval<std::span<element_type>>(),
+                                               std::declval<std::span<element_type>>(),
+                                               std::views::iota(coordinate_type{}, coordinate_type{})))>;
 
 public:
     /*!\name Associated types
      * \{
      */
     //!\copydoc seqan3::detail::alignment_matrix_column_major_range_base::value_type
-    using value_type = alignment_trace_matrix_proxy<coordinate_type,
-                                                    std::conditional_t<coordinate_only,
-                                                                       detail::ignore_t const,
-                                                                       trace_t>>;
+    using value_type =
+        alignment_trace_matrix_proxy<coordinate_type,
+                                     std::conditional_t<coordinate_only, detail::ignore_t const, trace_t>>;
     //!\brief Same as value type.
     using reference = value_type;
     //!\copydoc seqan3::detail::alignment_matrix_column_major_range_base::iterator
@@ -98,17 +98,17 @@ public:
     /*!\name Constructors, destructor and assignment
      * \{
      */
-     //!\brief Defaulted.
+    //!\brief Defaulted.
     constexpr alignment_trace_matrix_full_banded() = default;
-     //!\brief Defaulted.
+    //!\brief Defaulted.
     constexpr alignment_trace_matrix_full_banded(alignment_trace_matrix_full_banded const &) = default;
-     //!\brief Defaulted.
+    //!\brief Defaulted.
     constexpr alignment_trace_matrix_full_banded(alignment_trace_matrix_full_banded &&) = default;
-     //!\brief Defaulted.
+    //!\brief Defaulted.
     constexpr alignment_trace_matrix_full_banded & operator=(alignment_trace_matrix_full_banded const &) = default;
-     //!\brief Defaulted.
+    //!\brief Defaulted.
     constexpr alignment_trace_matrix_full_banded & operator=(alignment_trace_matrix_full_banded &&) = default;
-     //!\brief Defaulted.
+    //!\brief Defaulted.
     ~alignment_trace_matrix_full_banded() = default;
 
     /*!\brief Construction from two ranges and a band.
@@ -135,10 +135,9 @@ public:
         matrix_base_t::num_cols = static_cast<size_type>(std::ranges::distance(first) + 1);
         matrix_base_t::num_rows = static_cast<size_type>(std::ranges::distance(second) + 1);
 
-        band_col_index = std::min<int32_t>(std::max<int32_t>(band.upper_diagonal, 0),
-                                           matrix_base_t::num_cols - 1);
-        band_row_index = std::min<int32_t>(std::abs(std::min<int32_t>(band.lower_diagonal, 0)),
-                                           matrix_base_t::num_rows - 1);
+        band_col_index = std::min<int32_t>(std::max<int32_t>(band.upper_diagonal, 0), matrix_base_t::num_cols - 1);
+        band_row_index =
+            std::min<int32_t>(std::abs(std::min<int32_t>(band.lower_diagonal, 0)), matrix_base_t::num_rows - 1);
         band_size = band_col_index + band_row_index + 1;
 
         // Reserve one more cell to deal with last cell in the banded column which needs only the diagonal and up cell.
@@ -192,20 +191,20 @@ private:
         coordinate_type row_end{column_index_type{column_index}, row_index_type{static_cast<size_type>(slice_end)}};
         if constexpr (coordinate_only)
         {
-            return alignment_column_type{*this,
-                                         column_data_view_type{std::views::iota(std::move(row_begin),
-                                                                                std::move(row_end))}};
+            return alignment_column_type{
+                *this,
+                column_data_view_type{std::views::iota(std::move(row_begin), std::move(row_end))}};
         }
         else
         {
             matrix_coordinate band_begin{row_index_type{static_cast<size_type>(slice_begin)},
                                          column_index_type{column_index}};
-            size_type slice_size =  slice_end - slice_begin;
+            size_type slice_size = slice_end - slice_begin;
             // We need to jump to the offset.
-            auto col = views::zip(
-                            std::span<element_type>{std::addressof(matrix_base_t::data[band_begin]), slice_size},
-                            std::span<element_type>{std::addressof(matrix_base_t::cache_left[slice_begin]), slice_size},
-                            std::views::iota(std::move(row_begin), std::move(row_end)));
+            auto col =
+                views::zip(std::span<element_type>{std::addressof(matrix_base_t::data[band_begin]), slice_size},
+                           std::span<element_type>{std::addressof(matrix_base_t::cache_left[slice_begin]), slice_size},
+                           std::views::iota(std::move(row_begin), std::move(row_end)));
             return alignment_column_type{*this, column_data_view_type{std::move(col)}};
         }
     }
@@ -220,12 +219,13 @@ private:
         }
         else
         {
-            return {std::get<2>(*host_iter),        // the current coordinate.
-                    std::get<0>(*host_iter),        // the current cell.
-                    std::get<1>(*(host_iter + 1)),  // the last left cell to read from.
-                    std::get<1>(*host_iter),        // the next left cell to write to.
-                    matrix_base_t::cache_up         // the last up cell to read/write from/to.
-                    };
+            return {
+                std::get<2>(*host_iter),       // the current coordinate.
+                std::get<0>(*host_iter),       // the current cell.
+                std::get<1>(*(host_iter + 1)), // the last left cell to read from.
+                std::get<1>(*host_iter),       // the next left cell to write to.
+                matrix_base_t::cache_up        // the last up cell to read/write from/to.
+            };
         }
     }
 };
