@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -28,7 +28,7 @@ namespace seqan3
  * \stableapi{Since version 3.1.}
  */
 template <typename derived_type, auto size>
-class aminoacid_base : public alphabet_base<derived_type, size, char>, public aminoacid_empty_base
+class aminoacid_base : public aminoacid_empty_base, public alphabet_base<derived_type, size, char>
 {
 private:
     //!\brief Type of the base class.
@@ -112,22 +112,27 @@ public:
     }
 
 private:
-    //!\brief Implementation of #char_is_valid().
-    static constexpr std::array<bool, 256> valid_char_table{[]() constexpr {// init with false
-                                                                            std::array<bool, 256> ret{};
-
-    // the original valid chars and their lower cases
-    for (size_t rank = 0u; rank < derived_type::alphabet_size; ++rank)
+    // clang-format off
+    //!\brief Implementation of seqan3::aminoacid_base::char_is_valid().
+    static constexpr std::array<bool, 256> valid_char_table
     {
-        uint8_t c = derived_type::rank_to_char(rank);
-        ret[c] = true;
-        ret[to_lower(c)] = true;
-    }
+        []() constexpr {
+            std::array<bool, 256> ret{};
 
-    return ret;
-}()
-}; // namespace seqan3
-}
-;
+            ret.fill(false); // Default constructor does not initialise!
+
+            // the original valid chars and their lower cases
+            for (size_t rank = 0u; rank < derived_type::alphabet_size; ++rank)
+            {
+                uint8_t c = derived_type::rank_to_char(rank);
+                ret[c] = true;
+                ret[to_lower(c)] = true;
+            }
+
+            return ret;
+        }()
+    };
+};
+// clang-format on
 
 } // namespace seqan3
