@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -55,7 +55,8 @@ private:
 
     //!\brief Befriend seqan3::nucleotide_base.
     friend base_t;
-    //!\cond \brief Befriend seqan3::alphabet_base.
+    //!\cond
+    //!\brief Befriend seqan3::alphabet_base.
     friend base_t::base_t;
     //!\endcond
     //!\brief Befriend seqan3::rna15 so it can copy #char_to_rank.
@@ -93,67 +94,69 @@ private:
     static constexpr char_type
         rank_to_char_table[alphabet_size]{'A', 'B', 'C', 'D', 'G', 'H', 'K', 'M', 'N', 'R', 'S', 'T', 'V', 'W', 'Y'};
 
-    //!\copydoc seqan3::dna4::char_to_rank
-    static constexpr std::array<rank_type, 256> char_to_rank_table{[]() constexpr {std::array<rank_type, 256> ret{};
+    //!\copydoc seqan3::dna4::rank_complement_table
+    static constexpr rank_type rank_complement_table[alphabet_size]{
+        11, // T is complement of 'A'_dna15
+        12, // V is complement of 'B'_dna15
+        4,  // G is complement of 'C'_dna15
+        5,  // H is complement of 'D'_dna15
+        2,  // C is complement of 'G'_dna15
+        3,  // D is complement of 'H'_dna15
+        7,  // M is complement of 'K'_dna15
+        6,  // K is complement of 'M'_dna15
+        8,  // N is complement of 'N'_dna15
+        14, // Y is complement of 'R'_dna15
+        10, // S is complement of 'S'_dna15
+        0,  // A is complement of 'T'_dna15
+        1,  // B is complement of 'V'_dna15
+        13, // W is complement of 'W'_dna15
+        9   // R is complement of 'Y'_dna15
+    };
 
-    // initialize with UNKNOWN (std::array::fill unfortunately not constexpr)
-    for (auto & c : ret)
-        c = 8; // rank of 'N'
-
-    // reverse mapping for characters and their lowercase
-    for (size_t rnk = 0u; rnk < alphabet_size; ++rnk)
+    //!\copydoc seqan3::dna4::rank_complement
+    static constexpr rank_type rank_complement(rank_type const rank)
     {
-        ret[rank_to_char_table[rnk]] = rnk;
-        ret[to_lower(rank_to_char_table[rnk])] = rnk;
+        return rank_complement_table[rank];
     }
 
-    // set U equal to T
-    ret['U'] = ret['T'];
-    ret['u'] = ret['t'];
+    //!\copydoc seqan3::dna4::rank_to_char
+    static constexpr char_type rank_to_char(rank_type const rank)
+    {
+        return rank_to_char_table[rank];
+    }
 
-    return ret;
-}()
-}; // namespace seqan3
+    //!\copydoc seqan3::dna4::char_to_rank
+    static constexpr rank_type char_to_rank(char_type const chr)
+    {
+        using index_t = std::make_unsigned_t<char_type>;
+        return char_to_rank_table[static_cast<index_t>(chr)];
+    }
 
-//!\copydoc seqan3::dna4::rank_complement_table
-static constexpr rank_type rank_complement_table[alphabet_size]{
-    11, // T is complement of 'A'_dna15
-    12, // V is complement of 'B'_dna15
-    4,  // G is complement of 'C'_dna15
-    5,  // H is complement of 'D'_dna15
-    2,  // C is complement of 'G'_dna15
-    3,  // D is complement of 'H'_dna15
-    7,  // M is complement of 'K'_dna15
-    6,  // K is complement of 'M'_dna15
-    8,  // N is complement of 'N'_dna15
-    14, // Y is complement of 'R'_dna15
-    10, // S is complement of 'S'_dna15
-    0,  // A is complement of 'T'_dna15
-    1,  // B is complement of 'V'_dna15
-    13, // W is complement of 'W'_dna15
-    9   // R is complement of 'Y'_dna15
+    // clang-format off
+    //!\copydoc seqan3::dna4::char_to_rank
+    static constexpr std::array<rank_type, 256> char_to_rank_table
+    {
+        []() constexpr {
+            std::array<rank_type, 256> ret{};
+
+            ret.fill(8u); // initialize with UNKNOWN ('N')
+
+            // reverse mapping for characters and their lowercase
+            for (size_t rnk = 0u; rnk < alphabet_size; ++rnk)
+            {
+                ret[rank_to_char_table[rnk]] = rnk;
+                ret[to_lower(rank_to_char_table[rnk])] = rnk;
+            }
+
+            // set U equal to T
+            ret['U'] = ret['T'];
+            ret['u'] = ret['t'];
+
+            return ret;
+        }()
+    };
 };
-
-//!\copydoc seqan3::dna4::rank_complement
-static constexpr rank_type rank_complement(rank_type const rank)
-{
-    return rank_complement_table[rank];
-}
-
-//!\copydoc seqan3::dna4::rank_to_char
-static constexpr char_type rank_to_char(rank_type const rank)
-{
-    return rank_to_char_table[rank];
-}
-
-//!\copydoc seqan3::dna4::char_to_rank
-static constexpr rank_type char_to_rank(char_type const chr)
-{
-    using index_t = std::make_unsigned_t<char_type>;
-    return char_to_rank_table[static_cast<index_t>(chr)];
-}
-}
-;
+// clang-format on
 
 // ------------------------------------------------------------------
 // containers
@@ -200,7 +203,7 @@ constexpr dna15 operator""_dna15(char const c) noexcept
  *
  * \stableapi{Since version 3.1.}
  */
-inline dna15_vector operator""_dna15(char const * s, std::size_t n)
+SEQAN3_WORKAROUND_LITERAL dna15_vector operator""_dna15(char const * s, std::size_t n)
 {
     dna15_vector r;
     r.resize(n);
