@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -52,7 +52,8 @@ private:
 
     //!\brief Befriend seqan3::nucleotide_base.
     friend base_t;
-    //!\cond \brief Befriend seqan3::alphabet_base.
+    //!\cond
+    //!\brief Befriend seqan3::alphabet_base.
     friend base_t::base_t;
     //!\endcond
 
@@ -75,71 +76,72 @@ private:
     static constexpr char_type rank_to_char_table
         [alphabet_size]{'=', 'A', 'C', 'M', 'G', 'R', 'S', 'V', 'T', 'W', 'Y', 'H', 'K', 'D', 'B', 'N'};
 
-    //!\copydoc seqan3::dna4::char_to_rank_table
-    static constexpr std::array<rank_type, 256> char_to_rank_table{[]() constexpr {std::array<rank_type, 256> ret{};
+    //!\copydoc seqan3::dna4::rank_complement_table
+    static constexpr rank_type rank_complement_table[alphabet_size]{
+        15, // N is complement of '='_dna16sam  0
+        8,  // T is complement of 'A'_dna16sam  1
+        4,  // G is complement of 'C'_dna16sam  2
+        12, // K is complement of 'M'_dna16sam  3
+        2,  // C is complement of 'G'_dna16sam  4
+        10, // Y is complement of 'R'_dna16sam  5
+        6,  // S is complement of 'S'_dna16sam  6
+        14, // B is complement of 'V'_dna16sam  7
+        1,  // A is complement of 'T'_dna16sam  8
+        9,  // W is complement of 'W'_dna16sam  9
+        5,  // R is complement of 'Y'_dna16sam 10
+        13, // D is complement of 'H'_dna16sam 11
+        3,  // M is complement of 'K'_dna16sam 12
+        11, // H is complement of 'D'_dna16sam 13
+        7,  // V is complement of 'B'_dna16sam 14
+        15  // N is complement of 'N'_dna16sam 15
+    };
 
-    // initialize with UNKNOWN (std::array::fill unfortunately not constexpr)
-    for (auto & c : ret)
-        c = 15; // rank of 'N'
-
-    // reverse mapping for characters and their lowercase
-    for (size_t rnk = 0u; rnk < alphabet_size; ++rnk)
+    //!\copydoc seqan3::dna4::rank_complement
+    static constexpr rank_type rank_complement(rank_type const rank)
     {
-        ret[rank_to_char_table[rnk]] = rnk;
-        ret[to_lower(rank_to_char_table[rnk])] = rnk;
+        return rank_complement_table[rank];
     }
 
-    // set U equal to T
-    ret['U'] = ret['T'];
-    ret['u'] = ret['t'];
-
-    return ret;
-}()
-}; // namespace seqan3
-
-//!\copydoc seqan3::dna4::rank_complement_table
-static constexpr rank_type rank_complement_table[alphabet_size]{
-    15, // N is complement of '='_dna16sam  0
-    8,  // T is complement of 'A'_dna16sam  1
-    4,  // G is complement of 'C'_dna16sam  2
-    12, // K is complement of 'M'_dna16sam  3
-    2,  // C is complement of 'G'_dna16sam  4
-    10, // Y is complement of 'R'_dna16sam  5
-    6,  // S is complement of 'S'_dna16sam  6
-    14, // B is complement of 'V'_dna16sam  7
-    1,  // A is complement of 'T'_dna16sam  8
-    9,  // W is complement of 'W'_dna16sam  9
-    5,  // R is complement of 'Y'_dna16sam 10
-    13, // D is complement of 'H'_dna16sam 11
-    3,  // M is complement of 'K'_dna16sam 12
-    11, // H is complement of 'D'_dna16sam 13
-    7,  // V is complement of 'B'_dna16sam 14
-    15  // N is complement of 'N'_dna16sam 15
-};
-
-//!\copydoc seqan3::dna4::rank_complement
-static constexpr rank_type rank_complement(rank_type const rank)
-{
-    return rank_complement_table[rank];
-}
-
-/*!\copydoc seqan3::dna4::rank_to_char
+    /*!\copydoc seqan3::dna4::rank_to_char
      *
      * The representation is the same as in the SAM specifications (which is NOT in alphabetical order).
      */
-static constexpr char_type rank_to_char(rank_type const rank)
-{
-    return rank_to_char_table[rank];
-}
+    static constexpr char_type rank_to_char(rank_type const rank)
+    {
+        return rank_to_char_table[rank];
+    }
 
-//!\copydoc seqan3::dna4::char_to_rank
-static constexpr rank_type char_to_rank(char_type const chr)
-{
-    using index_t = std::make_unsigned_t<char_type>;
-    return char_to_rank_table[static_cast<index_t>(chr)];
-}
-}
-;
+    //!\copydoc seqan3::dna4::char_to_rank
+    static constexpr rank_type char_to_rank(char_type const chr)
+    {
+        using index_t = std::make_unsigned_t<char_type>;
+        return char_to_rank_table[static_cast<index_t>(chr)];
+    }
+
+    // clang-format off
+    //!\copydoc seqan3::dna4::char_to_rank_table
+    static constexpr std::array<rank_type, 256> char_to_rank_table{
+        []() constexpr {
+            std::array<rank_type, 256> ret{};
+
+            ret.fill(15u); // initialize with UNKNOWN ('N')
+
+            // reverse mapping for characters and their lowercase
+            for (size_t rnk = 0u; rnk < alphabet_size; ++rnk)
+            {
+                ret[rank_to_char_table[rnk]] = rnk;
+                ret[to_lower(rank_to_char_table[rnk])] = rnk;
+            }
+
+            // set U equal to T
+            ret['U'] = ret['T'];
+            ret['u'] = ret['t'];
+
+            return ret;
+        }()
+    };
+};
+// clang-format on
 
 // ------------------------------------------------------------------
 // containers
@@ -188,7 +190,7 @@ constexpr dna16sam operator""_dna16sam(char const c) noexcept
  *
  * \stableapi{Since version 3.1.}
  */
-inline dna16sam_vector operator""_dna16sam(char const * s, size_t n)
+SEQAN3_WORKAROUND_LITERAL dna16sam_vector operator""_dna16sam(char const * s, size_t n)
 {
     dna16sam_vector r;
     r.resize(n);
