@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -12,6 +12,8 @@
 
 #pragma once
 
+#include <algorithm>
+
 #include <seqan3/alphabet/alphabet_base.hpp>
 #include <seqan3/alphabet/detail/convert.hpp>
 #include <seqan3/alphabet/quality/concept.hpp>
@@ -44,7 +46,9 @@ private:
     //!\brief The base type.
     using base_t = alphabet_base<derived_type, size, char>;
 
-    //!\brief Befriend the base type so it can access #char_to_rank and #rank_to_char.
+    /*!\brief Befriend the base type so it can access seqan3::alphabet_base::char_to_rank
+     *        and seqan3::alphabet_base::rank_to_char.
+     */
     friend base_t;
 
     /*!\name Constructors, destructor and assignment
@@ -126,48 +130,55 @@ public:
     //!\}
 
 private:
-    //!\brief Phred to rank conversion table.
-    static constexpr std::array<rank_type, 256> phred_to_rank{[]() constexpr {std::array<rank_type, 256> ret{};
-
-    for (int64_t i = std::numeric_limits<phred_type>::lowest(); i <= std::numeric_limits<phred_type>::max(); ++i)
+    //!\copydoc seqan3::dna4::char_to_rank
+    static constexpr rank_type char_to_rank(char_type const chr)
     {
-        if (i < derived_type::offset_phred) // map too-small to smallest possible
-            ret[static_cast<rank_type>(i)] = 0;
-        else if (i >= derived_type::offset_phred + alphabet_size) // map too-large to highest possible
-            ret[static_cast<rank_type>(i)] = alphabet_size - 1;
-        else // map valid range to identity
-            ret[static_cast<rank_type>(i)] = i - derived_type::offset_phred;
+        int64_t difference = static_cast<int64_t>(chr) - static_cast<int64_t>(derived_type::offset_char);
+        return std::clamp<int64_t>(difference, 0, alphabet_size - 1);
     }
-    return ret;
-}()
-}; // namespace seqan3
 
-//!\brief Rank to phred conversion table.
-static constexpr std::array<phred_type, alphabet_size> rank_to_phred{
-    []() constexpr {std::array<phred_type, alphabet_size> ret{};
+    //!\copydoc seqan3::dna4::rank_to_char
+    static constexpr char_type rank_to_char(rank_type const rank)
+    {
+        return rank + derived_type::offset_char;
+    }
 
-for (size_t i = 0; i < alphabet_size; ++i)
-    ret[i] = i + derived_type::offset_phred;
+    // clang-format off
+    //!\brief Phred to rank conversion table.
+    static constexpr std::array<rank_type, 256> phred_to_rank
+    {
+        []() constexpr {
+            std::array<rank_type, 256> ret{};
 
-return ret;
-}
-()
-}
-;
+            for (int64_t i = std::numeric_limits<phred_type>::lowest();
+                 i <= std::numeric_limits<phred_type>::max();
+                 ++i)
+            {
+                if (i < derived_type::offset_phred) // map too-small to smallest possible
+                    ret[static_cast<rank_type>(i)] = 0;
+                else if (i >= derived_type::offset_phred + alphabet_size) // map too-large to highest possible
+                    ret[static_cast<rank_type>(i)] = alphabet_size - 1;
+                else // map valid range to identity
+                    ret[static_cast<rank_type>(i)] = i - derived_type::offset_phred;
+            }
 
-//!\copydoc seqan3::dna4::char_to_rank
-static constexpr rank_type char_to_rank(char_type const chr)
-{
-    int64_t difference = static_cast<int64_t>(chr) - static_cast<int64_t>(derived_type::offset_char);
-    return std::clamp<int64_t>(difference, 0, alphabet_size - 1);
-}
+            return ret;
+        }()
+    };
 
-//!\copydoc seqan3::dna4::rank_to_char
-static constexpr char_type rank_to_char(rank_type const rank)
-{
-    return rank + derived_type::offset_char;
-}
-}
-;
+    //!\brief Rank to phred conversion table.
+    static constexpr std::array<phred_type, alphabet_size> rank_to_phred
+    {
+        []() constexpr {
+            std::array<phred_type, alphabet_size> ret{};
+
+            for (size_t i = 0; i < alphabet_size; ++i)
+                ret[i] = i + derived_type::offset_phred;
+
+            return ret;
+        }()
+    };
+};
+// clang-format on
 
 } // namespace seqan3
