@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -95,13 +95,13 @@ public:
     //!\brief Delegate to base class if inheriting from non-pointer iterator.
     constexpr inherited_iterator_base(base_t it) noexcept(std::is_nothrow_move_constructible_v<base_t>)
         requires (!wrap_base)
-    : base_t{std::move(it)}
+        : base_t{std::move(it)}
     {}
 
     //!\brief Initialise member if deriving from pointer.
     constexpr inherited_iterator_base(base_t it) noexcept
         requires wrap_base
-    : member{std::move(it)}
+        : member{std::move(it)}
     {}
     //!\}
 
@@ -267,6 +267,12 @@ public:
     }
 
     //!\brief Non-member operator+ delegates to non-friend operator+.
+    //!\cond
+    // Make this function a function template. This means that constructible_from will be evaluated with the complete
+    // derived_t (which is instantiated in the second pass). If this wasn't a function template, the concept would have
+    // to be evaluated in the first pass, where derived_t is incomplete.
+    template <typename base_t_ = base_t>
+    //!\endcond
     constexpr friend derived_t operator+(difference_type const skip,
                                          derived_t const & it) noexcept(noexcept(skip + std::declval<base_t const &>()))
         requires requires (base_t const i, difference_type const n) { n + i; }
@@ -376,7 +382,7 @@ private:
             return *this;
     }
 
-    //!\copydoc as_base
+    //!\copydoc seqan3::detail::inherited_iterator_base::as_base
     constexpr base_t const & as_base() const & noexcept
     {
         if constexpr (wrap_base)
@@ -391,7 +397,7 @@ private:
         return static_cast<derived_t *>(this);
     }
 
-    //!\copydoc this_derived
+    //!\copydoc seqan3::detail::inherited_iterator_base::this_derived
     constexpr derived_t const * this_derived() const
     {
         return static_cast<derived_t const *>(this);
