@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -50,9 +50,6 @@ protected:
 
     //!\brief This friend declaration is required to allow non-const to const-construction.
     template <typename range_type2, template <typename...> typename derived_t_template2, typename... args2_t>
-        requires std::is_const_v<range_type>
-              && (!std::is_const_v<range_type2>) && std::is_same_v<std::remove_const_t<range_type>, range_type2>
-              && std::is_same_v<derived_t_template2<args2_t...>, derived_t_template<args_t...>>
     friend class random_access_iterator_base;
 
     //!\brief Because this is CRTP, we know the full derived type:
@@ -274,7 +271,7 @@ private:
         return static_cast<derived_t *>(this);
     }
 
-    //!\copydoc this_derived
+    //!\copydoc seqan3::detail::random_access_iterator_base::this_derived
     constexpr derived_t const * this_derived() const
     {
         return static_cast<derived_t const *>(this);
