@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -152,7 +152,8 @@ struct fields
     }
 
     static_assert(
-        []() constexpr {
+        []() constexpr
+        {
             for (size_t i = 0; i < as_array.size(); ++i)
                 for (size_t j = i + 1; j < as_array.size(); ++j)
                     if (as_array[i] == as_array[j])
