@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -74,33 +74,24 @@ protected:
                                  header_type & header,
                                  ref_seqs_type & /*tag*/);
 
-    template <typename align_type, typename ref_seqs_type>
-    void construct_alignment(align_type & align,
-                             std::vector<cigar> & cigar_vector,
-                             [[maybe_unused]] int32_t rid,
-                             [[maybe_unused]] ref_seqs_type & ref_seqs,
-                             [[maybe_unused]] int32_t ref_start,
-                             size_t ref_length);
-
-    void transfer_soft_clipping_to(std::vector<cigar> const & cigar_vector, int32_t & sc_begin, int32_t & sc_end) const;
-
-    template <typename stream_view_t>
-    void read_byte_field(stream_view_t && stream_view, std::byte & byte_target);
+    int32_t soft_clipping_at_front(std::vector<cigar> const & cigar_vector) const;
 
     template <typename stream_view_type, std::ranges::forward_range target_range_type>
     void read_forward_range_field(stream_view_type && stream_view, target_range_type & target);
 
-    template <typename stream_view_t, arithmetic arithmetic_target_type>
-    void read_arithmetic_field(stream_view_t && stream_view, arithmetic_target_type & arithmetic_target);
+    template <std::ranges::forward_range target_range_type>
+    void read_forward_range_field(std::string_view const str, target_range_type & target);
+
+    template <arithmetic arithmetic_target_type>
+    void read_arithmetic_field(std::string_view const & str, arithmetic_target_type & arithmetic_target);
 
     template <typename stream_view_type, typename ref_ids_type, typename ref_seqs_type>
     void read_header(stream_view_type && stream_view,
                      sam_file_header<ref_ids_type> & hdr,
                      ref_seqs_type & /*ref_id_to_pos_map*/);
 
-    template <typename stream_t, typename ref_ids_type>
-    void
-    write_header(stream_t & stream, sam_file_output_options const & options, sam_file_header<ref_ids_type> & header);
+    template <typename stream_t, typename header_type>
+    void write_header(stream_t & stream, sam_file_output_options const & options, header_type & header);
 };
 
 /*!\brief Checks for known reference ids or adds a new reference is and assigns a reference id to `ref_id`.
@@ -151,15 +142,13 @@ inline void format_sam_base::check_and_assign_ref_id(ref_id_type & ref_id,
     }
 }
 
-/*!\brief Transfer soft clipping information from the \p cigar_vector to \p sc_begin and \p sc_end.
+/*!\brief Returns the soft clipping value at the front of the \p cigar_vector or 0 if none present.
  * \param[in] cigar_vector The cigar information to parse for soft-clipping.
- * \param[out] sc_begin    The soft clipping at the beginning of the alignment to set.
- * \param[out] sc_end      The soft clipping at the end of the alignment to set.
  */
-inline void format_sam_base::transfer_soft_clipping_to(std::vector<cigar> const & cigar_vector,
-                                                       int32_t & sc_begin,
-                                                       int32_t & sc_end) const
+inline int32_t format_sam_base::soft_clipping_at_front(std::vector<cigar> const & cigar_vector) const
 {
+    int32_t sc_front{};
+
     // Checks if the given index in the cigar vector is a soft clip.
     auto soft_clipping_at = [&](size_t const index)
     {
@@ -183,112 +172,11 @@ inline void format_sam_base::transfer_soft_clipping_to(std::vector<cigar> const
 
     // check for soft clipping at the first two positions
     if (vector_size_at_least(1) && soft_clipping_at(0))
-        sc_begin = cigar_count_at(0);
+        sc_front = cigar_count_at(0);
     else if (vector_size_at_least(2) && hard_clipping_at(0) && soft_clipping_at(1))
-        sc_begin = cigar_count_at(1);
+        sc_front = cigar_count_at(1);
 
-    // Check for soft clipping at the last two positions. But only if the vector size has at least 2, respectively
-    // 3 elements. Accordingly, if the following arithmetics overflow they are protected by the corresponding
-    // if expressions below.
-    auto last_index = cigar_vector.size() - 1;
-    auto second_last_index = last_index - 1;
-
-    if (vector_size_at_least(2) && soft_clipping_at(last_index))
-        sc_end = cigar_count_at(last_index);
-    else if (vector_size_at_least(3) && hard_clipping_at(last_index) && soft_clipping_at(second_last_index))
-        sc_end = cigar_count_at(second_last_index);
-}
-
-/*!\brief Construct the field::alignment depending on the given information.
- * \tparam align_type      The alignment type.
- * \tparam ref_seqs_type   The type of reference sequences (might decay to ignore).
- * \param[in,out] align    The alignment (pair of aligned sequences) to fill.
- * \param[in] cigar_vector The cigar information to convert to an alignment.
- * \param[in] rid          The index of the reference sequence in header.ref_ids().
- * \param[in] ref_seqs     The reference sequence information.
- * \param[in] ref_start    The start position of the alignment in the reference sequence.
- * \param[in] ref_length   The length of the aligned reference sequence.
- */
-template <typename align_type, typename ref_seqs_type>
-inline void format_sam_base::construct_alignment(align_type & align,
-                                                 std::vector<cigar> & cigar_vector,
-                                                 [[maybe_unused]] int32_t rid,
-                                                 [[maybe_unused]] ref_seqs_type & ref_seqs,
-                                                 [[maybe_unused]] int32_t ref_start,
-                                                 size_t ref_length)
-{
-    if (rid > -1 && ref_start > -1 &&       // read is mapped
-        !cigar_vector.empty() &&            // alignment field was not empty
-        !std::ranges::empty(get<1>(align))) // seq field was not empty
-    {
-        if constexpr (!detail::decays_to_ignore_v<ref_seqs_type>)
-        {
-            assert(static_cast<size_t>(ref_start + ref_length) <= std::ranges::size(ref_seqs[rid]));
-            // copy over unaligned reference sequence part
-            assign_unaligned(get<0>(align), ref_seqs[rid] | views::slice(ref_start, ref_start + ref_length));
-        }
-        else
-        {
-            using unaligned_t = std::remove_cvref_t<detail::unaligned_seq_t<decltype(get<0>(align))>>;
-            auto dummy_seq = views::repeat_n(std::ranges::range_value_t<unaligned_t>{}, ref_length)
-                           | std::views::transform(detail::access_restrictor_fn{});
-            static_assert(std::same_as<unaligned_t, decltype(dummy_seq)>,
-                          "No reference information was given so the type of the first alignment tuple position"
-                          "must have an unaligned sequence type of a dummy sequence ("
-                          "views::repeat_n(dna5{}, size_t{}) | "
-                          "std::views::transform(detail::access_restrictor_fn{}))");
-
-            assign_unaligned(get<0>(align), dummy_seq); // assign dummy sequence
-        }
-
-        // insert gaps according to the cigar information
-        detail::alignment_from_cigar(align, cigar_vector);
-    }
-    else // not enough information for an alignment, assign an empty view/dummy_sequence
-    {
-        if constexpr (!detail::decays_to_ignore_v<ref_seqs_type>) // reference info given
-        {
-            assert(std::ranges::size(ref_seqs) > 0); // we assume that the given ref info is not empty
-            assign_unaligned(get<0>(align), ref_seqs[0] | views::slice(0, 0));
-        }
-        else
-        {
-            using unaligned_t = std::remove_cvref_t<detail::unaligned_seq_t<decltype(get<0>(align))>>;
-            assign_unaligned(get<0>(align),
-                             views::repeat_n(std::ranges::range_value_t<unaligned_t>{}, 0)
-                                 | std::views::transform(detail::access_restrictor_fn{}));
-        }
-    }
-}
-
-/*!\brief Reads std::byte fields using std::from_chars.
- * \tparam stream_view_t The type of the stream as a view.
- *
- * \param[in, out] stream_view  The stream view to iterate over.
- * \param[out] byte_target The std::byte object to store the parsed value.
- *
- * \throws seqan3::format_error if the character sequence in stream_view cannot be successfully converted to a value
- *         of type std::byte.
- */
-template <typename stream_view_t>
-inline void format_sam_base::read_byte_field(stream_view_t && stream_view, std::byte & byte_target)
-{
-    // unfortunately std::from_chars only accepts char const * so we need a buffer.
-    auto [ignore, end] = std::ranges::copy(stream_view, arithmetic_buffer.data());
-    (void)ignore;
-
-    uint8_t byte{};
-    // std::from_chars cannot directly parse into a std::byte
-    std::from_chars_result res = std::from_chars(arithmetic_buffer.begin(), end, byte, 16);
-
-    if (res.ec == std::errc::invalid_argument || res.ptr != end)
-        throw format_error{std::string("[CORRUPTED SAM FILE] The string '")
-                           + std::string(arithmetic_buffer.begin(), end) + "' could not be cast into type uint8_t."};
-
-    if (res.ec == std::errc::result_out_of_range)
-        throw format_error{std::string("[CORRUPTED SAM FILE] Casting '") + std::string(arithmetic_buffer.begin(), end)
-                           + "' into type uint8_t would cause an overflow."};
-    byte_target = std::byte{byte};
+    return sc_front;
 }
 
 /*!\brief Reads a range by copying from stream_view to target, converting values with seqan3::views::char_to.
@@ -320,32 +208,51 @@ inline void format_sam_base::read_forward_range_field(stream_view_type && stream
     }
 }
 
+/*!\brief Reads from `str` to `target`, converting values with seqan3::views::char_to.
+ * \tparam target_range_type The type of range to parse from input; must model std::ranges::forward_range.
+ *
+ * \param[in, out] str          The string_view to parse.
+ * \param[out]     target       The range to store the parsed sequence.
+ */
+template <std::ranges::forward_range target_range_type>
+inline void format_sam_base::read_forward_range_field(std::string_view const str, target_range_type & target)
+{
+    if (str.size() == 1 && str[0] == '*') // '*' denotes empty field
+        return;
+
+    if constexpr (std::assignable_from<target_range_type, std::string_view>)
+    {
+        target = str;
+    }
+    else
+    {
+        target.resize(str.size());
+        for (size_t i = 0; i < str.size(); ++i)
+            target[i] = assign_char_to(str[i], std::ranges::range_value_t<target_range_type>{});
+    }
+}
+
 /*!\brief Reads arithmetic fields using std::from_chars.
- * \tparam stream_view_t The type of the stream as a view.
  * \tparam arithmetic_target_type      The type of value to parse from input; must model seqan3::arithmetic.
  *
- * \param[in, out] stream_view  The stream view to iterate over.
+ * \param[in, out] str  The string_view to parse.
  * \param[out] arithmetic_target The arithmetic value object to store the parsed value.
  *
- * \throws seqan3::format_error if the character sequence in stream_view cannot be successfully converted to a value
+ * \throws seqan3::format_error if the character sequence in str cannot be successfully converted to a value
  *         of type arithmetic_target_type.
  */
-template <typename stream_view_t, arithmetic arithmetic_target_type>
-inline void format_sam_base::read_arithmetic_field(stream_view_t && stream_view,
+template <arithmetic arithmetic_target_type>
+inline void format_sam_base::read_arithmetic_field(std::string_view const & str,
                                                    arithmetic_target_type & arithmetic_target)
 {
-    // unfortunately std::from_chars only accepts char const * so we need a buffer.
-    auto [ignore, end] = std::ranges::copy(stream_view, arithmetic_buffer.data());
-    (void)ignore;
-    std::from_chars_result res = std::from_chars(arithmetic_buffer.begin(), end, arithmetic_target);
+    std::from_chars_result res = std::from_chars(str.begin(), str.end(), arithmetic_target);
 
-    if (res.ec == std::errc::invalid_argument || res.ptr != end)
-        throw format_error{std::string("[CORRUPTED SAM FILE] The string '")
-                           + std::string(arithmetic_buffer.begin(), end) + "' could not be cast into type "
-                           + detail::type_name_as_string<arithmetic_target_type>};
+    if (res.ec == std::errc::invalid_argument || res.ptr != str.end())
+        throw format_error{std::string("[CORRUPTED SAM FILE] The string '") + std::string(str.begin(), str.end())
+                           + "' could not be cast into type " + detail::type_name_as_string<arithmetic_target_type>};
 
     if (res.ec == std::errc::result_out_of_range)
-        throw format_error{std::string("[CORRUPTED SAM FILE] Casting '") + std::string(arithmetic_buffer.begin(), end)
+        throw format_error{std::string("[CORRUPTED SAM FILE] Casting '") + std::string(str.begin(), str.end())
                            + "' into type " + detail::type_name_as_string<arithmetic_target_type>
                            + " would cause an overflow."};
 }
@@ -373,7 +280,7 @@ inline void format_sam_base::read_header(stream_view_type && stream_view,
 {
     auto it = std::ranges::begin(stream_view);
     auto end = std::ranges::end(stream_view);
-    std::vector<char> string_buffer{};
+    std::string string_buffer{};
 
     auto make_tag = [](uint8_t char1, uint8_t char2) constexpr
     {
@@ -702,115 +609,117 @@ inline void format_sam_base::read_header(stream_view_type && stream_view,
  * according to the rules of the official
  * [SAM format specifications](https://samtools.github.io/hts-specs/SAMv1.pdf).
  */
-template <typename stream_t, typename ref_ids_type>
-inline void format_sam_base::write_header(stream_t & stream,
-                                          sam_file_output_options const & options,
-                                          sam_file_header<ref_ids_type> & header)
+template <typename stream_t, typename header_type>
+inline void
+format_sam_base::write_header(stream_t & stream, sam_file_output_options const & options, header_type & header)
 {
-    // -----------------------------------------------------------------
-    // Check Header
-    // -----------------------------------------------------------------
-
-    // (@HD) Check header line
-    // The format version string will be taken from the local member variable
-    if (!header.sorting.empty()
-        && !(header.sorting == "unknown" || header.sorting == "unsorted" || header.sorting == "queryname"
-             || header.sorting == "coordinate"))
-        throw format_error{"SAM format error: The header.sorting member must be "
-                           "one of [unknown, unsorted, queryname, coordinate]."};
-
-    if (!header.grouping.empty()
-        && !(header.grouping == "none" || header.grouping == "query" || header.grouping == "reference"))
-        throw format_error{"SAM format error: The header.grouping member must be "
-                           "one of [none, query, reference]."};
-
-    // (@SQ) Check Reference Sequence Dictionary lines
-
-    // TODO
-
-    // - sorting order be one of ...
-    // - grouping can be one of ...
-    // - reference names must be unique
-    // - ids of read groups must be unique
-    // - program ids need to be unique
-    // many more small semantic things, like fits REGEX
-
-    // -----------------------------------------------------------------
-    // Write Header
-    // -----------------------------------------------------------------
-    std::ostreambuf_iterator stream_it{stream};
-
-    // (@HD) Write header line [required].
-    stream << "@HD\tVN:";
-    std::ranges::copy(format_version, stream_it);
-
-    if (!header.sorting.empty())
-        stream << "\tSO:" << header.sorting;
-
-    if (!header.subsorting.empty())
-        stream << "\tSS:" << header.subsorting;
-
-    if (!header.grouping.empty())
-        stream << "\tGO:" << header.grouping;
-
-    detail::write_eol(stream_it, options.add_carriage_return);
-
-    // (@SQ) Write Reference Sequence Dictionary lines [required].
-    for (auto const & [ref_name, ref_info] : views::zip(header.ref_ids(), header.ref_id_info))
+    if constexpr (!detail::decays_to_ignore_v<header_type>)
     {
-        stream << "@SQ\tSN:";
+        // -----------------------------------------------------------------
+        // Check Header
+        // -----------------------------------------------------------------
 
-        std::ranges::copy(ref_name, stream_it);
+        // (@HD) Check header line
+        // The format version string will be taken from the local member variable
+        if (!header.sorting.empty()
+            && !(header.sorting == "unknown" || header.sorting == "unsorted" || header.sorting == "queryname"
+                 || header.sorting == "coordinate"))
+            throw format_error{"SAM format error: The header.sorting member must be "
+                               "one of [unknown, unsorted, queryname, coordinate]."};
 
-        stream << "\tLN:" << get<0>(ref_info);
+        if (!header.grouping.empty()
+            && !(header.grouping == "none" || header.grouping == "query" || header.grouping == "reference"))
+            throw format_error{"SAM format error: The header.grouping member must be "
+                               "one of [none, query, reference]."};
 
-        if (!get<1>(ref_info).empty())
-            stream << "\t" << get<1>(ref_info);
+        // (@SQ) Check Reference Sequence Dictionary lines
+
+        // TODO
+
+        // - sorting order be one of ...
+        // - grouping can be one of ...
+        // - reference names must be unique
+        // - ids of read groups must be unique
+        // - program ids need to be unique
+        // many more small semantic things, like fits REGEX
+
+        // -----------------------------------------------------------------
+        // Write Header
+        // -----------------------------------------------------------------
+        std::ostreambuf_iterator stream_it{stream};
+
+        // (@HD) Write header line [required].
+        stream << "@HD\tVN:";
+        std::ranges::copy(format_version, stream_it);
+
+        if (!header.sorting.empty())
+            stream << "\tSO:" << header.sorting;
+
+        if (!header.subsorting.empty())
+            stream << "\tSS:" << header.subsorting;
+
+        if (!header.grouping.empty())
+            stream << "\tGO:" << header.grouping;
 
         detail::write_eol(stream_it, options.add_carriage_return);
-    }
 
-    // Write read group (@RG) lines if specified.
-    for (auto const & read_group : header.read_groups)
-    {
-        stream << "@RG"
-               << "\tID:" << get<0>(read_group);
+        // (@SQ) Write Reference Sequence Dictionary lines [required].
+        for (auto const & [ref_name, ref_info] : views::zip(header.ref_ids(), header.ref_id_info))
+        {
+            stream << "@SQ\tSN:";
 
-        if (!get<1>(read_group).empty())
-            stream << "\t" << get<1>(read_group);
+            std::ranges::copy(ref_name, stream_it);
 
-        detail::write_eol(stream_it, options.add_carriage_return);
-    }
+            stream << "\tLN:" << get<0>(ref_info);
 
-    // Write program (@PG) lines if specified.
-    for (auto const & program : header.program_infos)
-    {
-        stream << "@PG"
-               << "\tID:" << program.id;
+            if (!get<1>(ref_info).empty())
+                stream << "\t" << get<1>(ref_info);
 
-        if (!program.name.empty())
-            stream << "\tPN:" << program.name;
+            detail::write_eol(stream_it, options.add_carriage_return);
+        }
 
-        if (!program.command_line_call.empty())
-            stream << "\tCL:" << program.command_line_call;
+        // Write read group (@RG) lines if specified.
+        for (auto const & read_group : header.read_groups)
+        {
+            stream << "@RG"
+                   << "\tID:" << get<0>(read_group);
 
-        if (!program.previous.empty())
-            stream << "\tPP:" << program.previous;
+            if (!get<1>(read_group).empty())
+                stream << "\t" << get<1>(read_group);
 
-        if (!program.description.empty())
-            stream << "\tDS:" << program.description;
+            detail::write_eol(stream_it, options.add_carriage_return);
+        }
 
-        if (!program.version.empty())
-            stream << "\tVN:" << program.version;
+        // Write program (@PG) lines if specified.
+        for (auto const & program : header.program_infos)
+        {
+            stream << "@PG"
+                   << "\tID:" << program.id;
 
-        detail::write_eol(stream_it, options.add_carriage_return);
-    }
+            if (!program.name.empty())
+                stream << "\tPN:" << program.name;
 
-    // Write comment (@CO) lines if specified.
-    for (auto const & comment : header.comments)
-    {
-        stream << "@CO\t" << comment;
-        detail::write_eol(stream_it, options.add_carriage_return);
+            if (!program.command_line_call.empty())
+                stream << "\tCL:" << program.command_line_call;
+
+            if (!program.previous.empty())
+                stream << "\tPP:" << program.previous;
+
+            if (!program.description.empty())
+                stream << "\tDS:" << program.description;
+
+            if (!program.version.empty())
+                stream << "\tVN:" << program.version;
+
+            detail::write_eol(stream_it, options.add_carriage_return);
+        }
+
+        // Write comment (@CO) lines if specified.
+        for (auto const & comment : header.comments)
+        {
+            stream << "@CO\t" << comment;
+            detail::write_eol(stream_it, options.add_carriage_return);
+        }
     }
 }
 
