@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -24,7 +24,22 @@
 namespace seqan3
 {
 
-/*!\brief Stores the header information of alignment files.
+/*!\brief Stores information of the program/tool that was used to create a SAM/BAM file.
+ * \ingroup io_sam_file
+ *
+ * \remark For a complete overview, take a look at \ref io_sam_file
+ */
+struct sam_file_program_info_t
+{
+    std::string id;                //!< A unique (file scope) id.
+    std::string name;              //!< The official name.
+    std::string command_line_call; //!< The command line call that produces the file.
+    std::string previous;          //!< The id of the previous program if program calls were chained.
+    std::string description;       //!< A description of the program and/or program call.
+    std::string version;           //!< The program/tool version.
+};
+
+/*!\brief Stores the header information of SAM/BAM files.
  * \ingroup io_sam_file
  *
  * \remark For a complete overview, take a look at \ref io_sam_file
@@ -63,19 +78,10 @@ public:
     {}
     //!\}
 
-    //!\brief Stores information of the program/tool that was used to create the file.
-    struct program_info_t
-    {
-        std::string id;                //!< A unique (file scope) id.
-        std::string name;              //!< The official name.
-        std::string command_line_call; //!< The command line call that produces the file.
-        std::string previous;          //!< The id of the previous program if program calls were chained.
-        std::string description;       //!< A description of the program and/or program call.
-        std::string version;           //!< The program/tool version.
-    };
-
-    std::string format_version; //!< The file format version. Note: this is overwritten by our formats on output.
-    std::string sorting;        //!< The sorting of the file. SAM: [unknown, unsorted, queryname, coordinate].
+    using program_info_t =
+        sam_file_program_info_t; //!< Stores information of the program/tool that was used to create the file.
+    std::string format_version;  //!< The file format version. Note: this is overwritten by our formats on output.
+    std::string sorting;         //!< The sorting of the file. SAM: [unknown, unsorted, queryname, coordinate].
     std::string
         subsorting; //!< The sub-sorting of the file. SAM: [unknown, unsorted, queryname, coordinate](:[A-Za-z0-9_-]+)+.
     std::string grouping; //!< The grouping of the file. SAM: [none, query, reference].
@@ -168,7 +174,7 @@ public:
      *           primary assembly.
      * * **AN:** Alternative reference sequence names. A comma-separated list of alternative names that tools may use
      *           when referring to this reference sequence. These alternative names are not used elsewhere within the
-     *           SAM file; in  particular, they must not appear in alignment records’ RNAME or RNEXT fields. regular
+     *           SAM file; in  particular, they must not appear in SAM records’ RNAME or RNEXT fields. regular
      *           expression : name (, name )* where name is [0-9A-Za-z][0-9A-Za-z*+.@ \|-]*
      * * **AS:** Genome assembly identifier.
      * * **M5:** MD5 checksum of the sequence.  See Section 1.3.1
