@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -44,7 +44,7 @@ namespace seqan3
 // sam_file_output
 // ----------------------------------------------------------------------------
 
-/*!\brief A class for writing alignment files, e.g. SAM, BAL, BLAST, ...
+/*!\brief A class for writing SAM files, both SAM and its binary representation BAM are supported.
  * \ingroup io_sam_file
  * \tparam selected_field_ids   A seqan3::fields type with the list and order of
  *                              fields IDs; only relevant if these can't be deduced.
@@ -59,10 +59,8 @@ namespace seqan3
  */
 template <detail::fields_specialisation selected_field_ids_ = fields<field::seq,
                                                                      field::id,
-                                                                     field::offset,
                                                                      field::ref_id,
                                                                      field::ref_offset,
-                                                                     field::alignment,
                                                                      field::cigar,
                                                                      field::mapq,
                                                                      field::qual,
@@ -90,10 +88,8 @@ public:
     //!\brief The subset of seqan3::field IDs that are valid for this file.
     using field_ids = fields<field::seq,
                              field::id,
-                             field::offset,
                              field::ref_id,
                              field::ref_offset,
-                             field::alignment,
                              field::cigar,
                              field::mapq,
                              field::flag,
@@ -102,14 +98,24 @@ public:
                              field::tags,
                              field::header_ptr>;
 
+    static_assert(!selected_field_ids::contains(field::offset),
+                  "The field::offset is deprecated. It is already stored in the field::cigar as soft clipping (S) "
+                  "at the front and not needed otherwise.");
+
+    static_assert(!selected_field_ids::contains(field::alignment),
+                  "The seqan3::field::alignment was removed from the allowed fields for seqan3::sam_file_output. "
+                  "Only seqan3::field::cigar is supported. seqan3::cigar_from_alignment on how to get a CIGAR string "
+                  "from an alignment.");
+
     static_assert(
-        []() constexpr {
+        []() constexpr
+        {
             for (field f : selected_field_ids::as_array)
                 if (!field_ids::contains(f))
                     return false;
             return true;
         }(),
-        "You selected a field that is not valid for alignment files, "
+        "You selected a field that is not valid for SAM files, "
         "please refer to the documentation of "
         "seqan3::sam_file_output::field_ids for the accepted values.");
 
@@ -149,8 +155,24 @@ public:
     sam_file_output(sam_file_output &&) = default;
     //!\brief Move assignment is defaulted.
     sam_file_output & operator=(sam_file_output &&) = default;
-    //!\brief Destructor is defaulted.
-    ~sam_file_output() = default;
+    //!\brief The destructor will write the header if it has not been written before.
+    ~sam_file_output()
+    {
+        if (header_has_been_written)
+            return;
+
+        assert(!format.valueless_by_exception());
+
+        std::visit(
+            [&](auto & f)
+            {
+                if constexpr (std::same_as<ref_ids_type, ref_info_not_given>)
+                    f.write_header(*secondary_stream, options, std::ignore);
+                else
+                    f.write_header(*secondary_stream, options, *header_ptr);
+            },
+            format);
+    }
 
     /*!\brief Construct from filename.
      * \param[in] filename      Path to the file you wish to open.
@@ -278,7 +300,8 @@ public:
         sam_file_output{filename, selected_field_ids{}}
 
     {
-        initialise_header_information(ref_ids, ref_lengths);
+        initialise_header_information(std::forward<ref_ids_type_>(ref_ids),
+                                      std::forward<ref_lengths_type>(ref_lengths));
     }
 
     /*!\brief Construct from an existing stream and with specified format.
@@ -314,7 +337,8 @@ public:
                     selected_field_ids const & SEQAN3_DOXYGEN_ONLY(fields_tag) = selected_field_ids{}) :
         sam_file_output{std::forward<stream_type>(stream), file_format{}, selected_field_ids{}}
     {
-        initialise_header_information(ref_ids, ref_lengths);
+        initialise_header_information(std::forward<ref_ids_type_>(ref_ids),
+                                      std::forward<ref_lengths_type>(ref_lengths));
     }
     //!\}
 
@@ -385,18 +409,15 @@ public:
     void push_back(record_t && r)
         requires detail::record_like<record_t>
     {
-        using default_align_t = std::pair<std::span<gapped<char>>, std::span<gapped<char>>>;
         using default_mate_t = std::tuple<std::string_view, std::optional<int32_t>, int32_t>;
 
         write_record(detail::get_or<field::header_ptr>(r, nullptr),
                      detail::get_or<field::seq>(r, std::string_view{}),
                      detail::get_or<field::qual>(r, std::string_view{}),
                      detail::get_or<field::id>(r, std::string_view{}),
-                     detail::get_or<field::offset>(r, 0u),
                      detail::get_or<field::ref_seq>(r, std::string_view{}),
                      detail::get_or<field::ref_id>(r, std::ignore),
                      detail::get_or<field::ref_offset>(r, std::optional<int32_t>{}),
-                     detail::get_or<field::alignment>(r, default_align_t{}),
                      detail::get_or<field::cigar>(r, std::vector<cigar>{}),
                      detail::get_or<field::flag>(r, sam_flag::none),
                      detail::get_or<field::mapq>(r, 0u),
@@ -431,7 +452,6 @@ public:
     void push_back(tuple_t && t)
         requires tuple_like<tuple_t> && (!detail::record_like<tuple_t>)
     {
-        using default_align_t = std::pair<std::span<gapped<char>>, std::span<gapped<char>>>;
         using default_mate_t = std::tuple<std::string_view, std::optional<int32_t>, int32_t>;
 
         // index_of might return npos, but this will be handled well by get_or_ignore (and just return ignore)
@@ -439,11 +459,9 @@ public:
                      detail::get_or<selected_field_ids::index_of(field::seq)>(t, std::string_view{}),
                      detail::get_or<selected_field_ids::index_of(field::qual)>(t, std::string_view{}),
                      detail::get_or<selected_field_ids::index_of(field::id)>(t, std::string_view{}),
-                     detail::get_or<selected_field_ids::index_of(field::offset)>(t, 0u),
                      detail::get_or<selected_field_ids::index_of(field::ref_seq)>(t, std::string_view{}),
                      detail::get_or<selected_field_ids::index_of(field::ref_id)>(t, std::ignore),
                      detail::get_or<selected_field_ids::index_of(field::ref_offset)>(t, std::optional<int32_t>{}),
-                     detail::get_or<selected_field_ids::index_of(field::alignment)>(t, default_align_t{}),
                      detail::get_or<selected_field_ids::index_of(field::cigar)>(t, std::vector<cigar>{}),
                      detail::get_or<selected_field_ids::index_of(field::flag)>(t, sam_flag::none),
                      detail::get_or<selected_field_ids::index_of(field::mapq)>(t, 0u),
@@ -592,6 +610,9 @@ public:
 
 protected:
     //!\privatesection
+    //!\brief This is needed during deconstruction to know whether a header still needs to be written.
+    bool header_has_been_written{false};
+
     //!\brief A larger (compared to stl default) stream buffer to use when reading from a file.
     std::vector<char> stream_buffer{std::vector<char>(1'000'000)};
 
@@ -637,7 +658,7 @@ protected:
 
         header_ptr = std::make_unique<sam_file_header<ref_ids_type>>(std::forward<ref_ids_type_>(ref_ids));
 
-        for (int32_t idx = 0; idx < std::ranges::distance(ref_ids); ++idx)
+        for (int32_t idx = 0; idx < std::ranges::distance(header_ptr->ref_ids()); ++idx)
         {
             header_ptr->ref_id_info.emplace_back(ref_lengths[idx], "");
 
@@ -659,7 +680,7 @@ protected:
     template <typename record_header_ptr_t, typename... pack_type>
     void write_record(record_header_ptr_t && record_header_ptr, pack_type &&... remainder)
     {
-        static_assert((sizeof...(pack_type) == 15), "Wrong parameter list passed to write_record.");
+        static_assert((sizeof...(pack_type) == 13), "Wrong parameter list passed to write_record.");
 
         assert(!format.valueless_by_exception());
 
@@ -690,6 +711,8 @@ protected:
                 }
             },
             format);
+
+        header_has_been_written = true; // when writing a record, the header is written automatically
     }
 
     //!\brief Befriend iterator so it can access the buffers.
