@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -310,15 +310,20 @@ private:
             for (; (it != e) && ((!is_id)(*it)); ++it)
             {
                 if ((is_space || is_digit)(*it))
-                    continue;
-                else if (!is_legal_alph(*it))
                 {
+                    continue;
+                }
+                else if (is_legal_alph(*it))
+                {
+                    seq.push_back(assign_char_to(*it, std::ranges::range_value_t<seq_type>{}));
+                }
+                else
+                {
+
                     throw parse_error{std::string{"Encountered an unexpected letter: "} + "char_is_valid_for<"
                                       + detail::type_name_as_string<seq_legal_alph_type>
                                       + "> evaluated to false on " + detail::make_printable(*it)};
                 }
-
-                seq.push_back(assign_char_to(*it, std::ranges::range_value_t<seq_type>{}));
             }
 
 #else  // ↑↑↑ WORKAROUND | ORIGINAL ↓↓↓
