@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -390,7 +390,8 @@ public:
                              field::offset>;
 
     static_assert(
-        []() constexpr {
+        []() constexpr
+        {
             for (field f : selected_field_ids::as_array)
                 if (!field_ids::contains(f))
                     return false;
@@ -400,7 +401,8 @@ public:
         "of structure_file_input::field_ids for the accepted values.");
 
     static_assert(
-        []() constexpr {
+        []() constexpr
+        {
             return !(selected_field_ids::contains(field::structured_seq)
                      && (selected_field_ids::contains(field::seq) || (selected_field_ids::contains(field::structure))));
         }(),
