@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -70,29 +70,6 @@ template <typename t>
 concept arithmetic = std::is_arithmetic_v<t>;
 //!\endcond
 
-/*!\interface seqan3::floating_point <>
- * \ingroup utility_concept
- * \brief An alias for `std::floating_point<t>`.
- *
- * \details
- *
- * \sa https://en.cppreference.com/w/cpp/concepts/floating_point
- *
- * \deprecated Use std::floating_point<t> instead.
- *
- * \noapi
- */
-//!\cond
-namespace deprecated
-{
-template <typename t>
-concept floating_point = arithmetic<t> && std::is_floating_point_v<t>;
-} // namespace deprecated
-
-template <typename t>
-SEQAN3_DEPRECATED_330 constexpr bool floating_point = deprecated::floating_point<t>;
-//!\endcond
-
 /*!\interface seqan3::builtin_character <>
  * \ingroup utility_concept
  * \extends std::integral
