@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -85,7 +85,7 @@ public:
     constexpr auto begin() const noexcept
         requires const_iterable_range<urng_t>
     {
-        return basic_iterator<decltype(std::ranges::cbegin(urng))>{std::ranges::cbegin(urng)};
+        return basic_iterator<decltype(std::ranges::begin(urng))>{std::ranges::begin(urng)};
     }
 
     /*!\brief Returns the sentinel to the end of the range.
@@ -109,7 +109,7 @@ public:
         requires const_iterable_range<urng_t>
     {
         if constexpr (std::ranges::common_range<urng_t>)
-            return basic_iterator<decltype(std::ranges::cend(urng))>{std::ranges::cend(urng)};
+            return basic_iterator<decltype(std::ranges::end(urng))>{std::ranges::end(urng)};
         else
             return std::ranges::cend(urng);
     }
