@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -175,7 +175,7 @@ public:
     constexpr const_iterator begin() const noexcept
         requires const_iterable_range<underlying_range_type>
     {
-        return {std::ranges::cbegin(u_range), std::ranges::cbegin(u_range), std::ranges::cend(u_range)};
+        return {std::ranges::begin(u_range), std::ranges::begin(u_range), std::ranges::end(u_range)};
     }
 
     /*!\brief Returns an iterator to the element following the last element of the range.
@@ -200,7 +200,7 @@ public:
     constexpr const_iterator end() const noexcept
         requires const_iterable_range<underlying_range_type>
     {
-        return {back_iterator, std::ranges::cbegin(u_range), std::ranges::cend(u_range)};
+        return {back_iterator, std::ranges::begin(u_range), std::ranges::end(u_range)};
     }
     //!\}
 
@@ -254,7 +254,6 @@ class pairwise_combine_view<underlying_range_type>::basic_iterator :
 private:
     //!\brief Friend declaration for iterator with different range const-ness.
     template <typename other_range_type>
-        requires std::same_as<std::remove_const_t<range_type>, std::remove_const_t<other_range_type>>
     friend class basic_iterator;
 
     //!\brief Alias type for the iterator over the passed range type.
