@@ -1,6 +1,8 @@
 #include <iostream>
 
-#include <sdsl/bit_vectors.hpp>
+#include <sdsl/int_vector.hpp>
+#include <sdsl/rank_support_v.hpp>
+#include <sdsl/rrr_vector.hpp>
 
 using namespace std;
 using namespace sdsl;
