@@ -1,7 +1,8 @@
 #include <iostream>
 #include <string>
 
-#include <sdsl/suffix_trees.hpp>
+#include <sdsl/cst_sada.hpp>
+#include <sdsl/cst_sct3.hpp>
 
 using namespace std;
 using namespace sdsl;
@@ -22,10 +23,16 @@ int main(int argc, char * argv[])
 
     auto root = cst.root();
 
-    for (auto & child : cst.children(root)) { std::cout << "sct3 id = " << cst.id(child) << std::endl; }
+    for (auto & child : cst.children(root))
+    {
+        std::cout << "sct3 id = " << cst.id(child) << std::endl;
+    }
 
     csts_t csts;
     construct(csts, argv[1], 1);
     auto roots = csts.root();
-    for (auto child : csts.children(roots)) { std::cout << "sada id = " << csts.id(child) << std::endl; }
+    for (auto child : csts.children(roots))
+    {
+        std::cout << "sada id = " << csts.id(child) << std::endl;
+    }
 }
