@@ -12,33 +12,41 @@
  * This group contains data structures which support an sdsl::bit_vector with the rank method.
  */
 
+#include <iosfwd>
+#include <stdint.h>
+#include <string>
+
+#include <sdsl/bits.hpp>
 #include <sdsl/int_vector.hpp>
 
 //! Namespace for the succinct data structure library.
 namespace sdsl
 {
+class structure_tree_node;
 
 //! The base class of classes supporting rank_queries for a sdsl::bit_vector in constant time.
 /*!
  */
 class rank_support
 {
-  protected:
-    const bit_vector * m_v; //!< Pointer to the rank supported bit_vector
-  public:
+protected:
+    bit_vector const * m_v; //!< Pointer to the rank supported bit_vector
+
+public:
     typedef bit_vector::size_type size_type;
 
     //! Constructor
     /*!\param v The supported bit_vector.
      */
-    rank_support(const bit_vector * v = nullptr);
+    rank_support(bit_vector const * v = nullptr);
     //! Copy constructor
-    rank_support(const rank_support &) = default;
+    rank_support(rank_support const &) = default;
     rank_support(rank_support &&) = default;
-    rank_support & operator=(const rank_support &) = default;
+    rank_support & operator=(rank_support const &) = default;
     rank_support & operator=(rank_support &&) = default;
     //! Destructor
-    virtual ~rank_support() {}
+    virtual ~rank_support()
+    {}
 
     //! Answers rank queries for the supported bit_vector.
     /*!	\param i Argument for the length of the prefix v[0..i-1].
@@ -57,16 +65,16 @@ class rank_support
     /*!\param in In-Stream to load the rank_support data from.
      * \param v The supported bit_vector.
      */
-    virtual void load(std::istream & in, const bit_vector * v = nullptr) = 0;
+    virtual void load(std::istream & in, bit_vector const * v = nullptr) = 0;
     //! Sets the supported bit_vector to the given pointer.
     /*!\param v The new bit_vector to support.
      *  \note Method init has to be called before the next call of rank.
      *  \sa init, rank
      */
-    virtual void set_vector(const bit_vector * v = nullptr) = 0;
+    virtual void set_vector(bit_vector const * v = nullptr) = 0;
 };
 
-inline rank_support::rank_support(const bit_vector * v)
+inline rank_support::rank_support(bit_vector const * v)
 {
     m_v = v;
 }
@@ -78,13 +86,25 @@ struct rank_support_trait
 {
     typedef rank_support::size_type size_type;
 
-    static size_type args_in_the_word(uint64_t, uint64_t &) { return 0; }
+    static size_type args_in_the_word(uint64_t, uint64_t &)
+    {
+        return 0;
+    }
 
-    static uint32_t word_rank(const uint64_t *, size_type) { return 0; }
+    static uint32_t word_rank(uint64_t const *, size_type)
+    {
+        return 0;
+    }
 
-    static uint32_t full_word_rank(const uint64_t *, size_type) { return 0; }
+    static uint32_t full_word_rank(uint64_t const *, size_type)
+    {
+        return 0;
+    }
 
-    static uint64_t init_carry() { return 0; }
+    static uint64_t init_carry()
+    {
+        return 0;
+    }
 };
 
 template <>
@@ -92,16 +112,25 @@ struct rank_support_trait<0, 1>
 {
     typedef rank_support::size_type size_type;
 
-    static size_type args_in_the_word(uint64_t w, uint64_t &) { return bits::cnt(~w); }
+    static size_type args_in_the_word(uint64_t w, uint64_t &)
+    {
+        return bits::cnt(~w);
+    }
 
-    static uint32_t word_rank(const uint64_t * data, size_type idx)
+    static uint32_t word_rank(uint64_t const * data, size_type idx)
     {
         return bits::cnt((~*(data + (idx >> 6))) & bits::lo_set[idx & 0x3F]);
     }
 
-    static uint32_t full_word_rank(const uint64_t * data, size_type idx) { return bits::cnt((~*(data + (idx >> 6)))); }
+    static uint32_t full_word_rank(uint64_t const * data, size_type idx)
+    {
+        return bits::cnt((~*(data + (idx >> 6))));
+    }
 
-    static uint64_t init_carry() { return 0; }
+    static uint64_t init_carry()
+    {
+        return 0;
+    }
 };
 
 template <>
@@ -109,16 +138,25 @@ struct rank_support_trait<1, 1>
 {
     typedef rank_support::size_type size_type;
 
-    static size_type args_in_the_word(uint64_t w, uint64_t &) { return bits::cnt(w); }
+    static size_type args_in_the_word(uint64_t w, uint64_t &)
+    {
+        return bits::cnt(w);
+    }
 
-    static uint32_t word_rank(const uint64_t * data, size_type idx)
+    static uint32_t word_rank(uint64_t const * data, size_type idx)
     {
         return bits::cnt(*(data + (idx >> 6)) & bits::lo_set[idx & 0x3F]);
     }
 
-    static uint32_t full_word_rank(const uint64_t * data, size_type idx) { return bits::cnt(*(data + (idx >> 6))); }
+    static uint32_t full_word_rank(uint64_t const * data, size_type idx)
+    {
+        return bits::cnt(*(data + (idx >> 6)));
+    }
 
-    static uint64_t init_carry() { return 0; }
+    static uint64_t init_carry()
+    {
+        return 0;
+    }
 };
 
 template <>
@@ -126,23 +164,29 @@ struct rank_support_trait<10, 2>
 {
     typedef rank_support::size_type size_type;
 
-    static size_type args_in_the_word(uint64_t w, uint64_t & carry) { return bits::cnt10(w, carry); }
+    static size_type args_in_the_word(uint64_t w, uint64_t & carry)
+    {
+        return bits::cnt10(w, carry);
+    }
 
-    static uint32_t word_rank(const uint64_t * data, size_type idx)
+    static uint32_t word_rank(uint64_t const * data, size_type idx)
     {
         data = data + (idx >> 6);
         uint64_t carry = (idx > 63) ? *(data - 1) >> 63 : 0;
         return bits::cnt(bits::map10(*data, carry) & bits::lo_set[idx & 0x3F]);
     }
 
-    static uint32_t full_word_rank(const uint64_t * data, size_type idx)
+    static uint32_t full_word_rank(uint64_t const * data, size_type idx)
     {
         data = data + (idx >> 6);
         uint64_t carry = (idx > 63) ? *(data - 1) >> 63 : 0;
         return bits::cnt(bits::map10(*data, carry));
     }
 
-    static uint64_t init_carry() { return 0; }
+    static uint64_t init_carry()
+    {
+        return 0;
+    }
 };
 
 template <>
@@ -150,23 +194,29 @@ struct rank_support_trait<01, 2>
 {
     typedef rank_support::size_type size_type;
 
-    static size_type args_in_the_word(uint64_t w, uint64_t & carry) { return bits::cnt01(w, carry); }
+    static size_type args_in_the_word(uint64_t w, uint64_t & carry)
+    {
+        return bits::cnt01(w, carry);
+    }
 
-    static uint32_t word_rank(const uint64_t * data, size_type idx)
+    static uint32_t word_rank(uint64_t const * data, size_type idx)
     {
         data = data + (idx >> 6);
         uint64_t carry = (idx > 63) ? *(data - 1) >> 63 : 1;
         return bits::cnt(bits::map01(*data, carry) & bits::lo_set[idx & 0x3F]);
     }
 
-    static uint32_t full_word_rank(const uint64_t * data, size_type idx)
+    static uint32_t full_word_rank(uint64_t const * data, size_type idx)
     {
         data = data + (idx >> 6);
         uint64_t carry = (idx > 63) ? *(data - 1) >> 63 : 1;
         return bits::cnt(bits::map01(*data, carry));
     }
 
-    static uint64_t init_carry() { return 1; }
+    static uint64_t init_carry()
+    {
+        return 1;
+    }
 };
 
 template <>
@@ -181,21 +231,24 @@ struct rank_support_trait<00, 2>
         return res;
     }
 
-    static uint32_t word_rank(const uint64_t * data, size_type idx)
+    static uint32_t word_rank(uint64_t const * data, size_type idx)
     {
         data = data + (idx >> 6);
         uint64_t carry = (idx > 63) ? *(data - 1) >> 63 : 1;
         return bits::cnt((~(*data | ((*data) << 1 | carry))) & bits::lo_set[idx & 0x3F]);
     }
 
-    static uint32_t full_word_rank(const uint64_t * data, size_type idx)
+    static uint32_t full_word_rank(uint64_t const * data, size_type idx)
     {
         data = data + (idx >> 6);
         uint64_t carry = (idx > 63) ? *(data - 1) >> 63 : 1;
         return bits::cnt(~(*data | ((*data) << 1 | carry)));
     }
 
-    static uint64_t init_carry() { return 1; }
+    static uint64_t init_carry()
+    {
+        return 1;
+    }
 };
 
 template <>
@@ -210,27 +263,34 @@ struct rank_support_trait<11, 2>
         return res;
     }
 
-    static uint32_t word_rank(const uint64_t * data, size_type idx)
+    static uint32_t word_rank(uint64_t const * data, size_type idx)
     {
         data = data + (idx >> 6);
         uint64_t carry = (idx > 63) ? *(data - 1) >> 63 : 0;
         return bits::cnt((*data & ((*data) << 1 | carry)) & bits::lo_set[idx & 0x3F]);
     }
 
-    static uint32_t full_word_rank(const uint64_t * data, size_type idx)
+    static uint32_t full_word_rank(uint64_t const * data, size_type idx)
     {
         data = data + (idx >> 6);
         uint64_t carry = (idx > 63) ? *(data - 1) >> 63 : 0;
         return bits::cnt(*data & ((*data) << 1 | carry));
     }
 
-    static uint64_t init_carry() { return 0; }
+    static uint64_t init_carry()
+    {
+        return 0;
+    }
 };
 
-} // end namespace sdsl
+} // namespace sdsl
 
+// clang-format off
+// Cyclic includes start
 #include <sdsl/rank_support_scan.hpp>
 #include <sdsl/rank_support_v.hpp>
 #include <sdsl/rank_support_v5.hpp>
+// Cyclic includes end
+// clang-format on
 
-#endif // end file
+#endif
