@@ -8,16 +8,26 @@
 #ifndef INCLUDED_SDSL_SUFFIX_ARRAYS
 #define INCLUDED_SDSL_SUFFIX_ARRAYS
 
-#include <sdsl/sdsl_concepts.hpp>
-
 /** \defgroup csa Compressed Suffix Arrays (CSA) */
 
+#include <stdint.h>
+
+#include <sdsl/csa_alphabet_strategy.hpp>
+#include <sdsl/csa_sada.hpp>
+#include <sdsl/csa_sampling_strategy.hpp>
+#include <sdsl/csa_wt.hpp>
+#include <sdsl/enc_vector.hpp>
+#include <sdsl/wt_int.hpp>
+
+// clang-format off
+// Cyclic includes start
+#include <sdsl/sdsl_concepts.hpp>
 #include <sdsl/construct.hpp>
 #include <sdsl/csa_bitcompressed.hpp>
-#include <sdsl/csa_sada.hpp>
-#include <sdsl/csa_wt.hpp>
 #include <sdsl/suffix_array_algorithm.hpp>
 #include <sdsl/wavelet_trees.hpp>
+// Cyclic includes end
+// clang-format on
 
 namespace sdsl
 {
