@@ -2,10 +2,10 @@
 #include <regex>
 #include <sstream>
 
-#include <sdsl/suffix_trees.hpp>
+#include <sdsl/csa_bitcompressed.hpp>
+#include <sdsl/cst_sct3.hpp>
 
 using namespace sdsl;
-using namespace std;
 
 std::string format("%3I%3S %3s %3P %3p %3L %3B  %T");
 std::string header("  i SA ISA PSI  LF LCP BWT  TEXT");
@@ -16,21 +16,21 @@ typedef csa_bitcompressed<int_alphabet<>> csa_int_t;
 typedef cst_sct3<> cst_byte_t;
 typedef cst_sct3<csa_int_t> cst_int_t;
 
-void print_usage(const char * command)
+void print_usage(char const * command)
 {
-    cout << "\
+    std::cout << "\
 A pretty printer for suffix array/tree members.\n\
 Transforms each input line into a CST and outputs\n\
 formatted suffix array/tree members.\n\
 Usage: " << command
-         << " X \"[FORMAT]\" \"[HEADER]\" \"[SENTINEL]\"\n\
+              << " X \"[FORMAT]\" \"[HEADER]\" \"[SENTINEL]\"\n\
 X       : Input is interpreted dependent on X.\n\
          X=1: byte sequence.\n\
          X=d: sequence of decimal numbers.\n\
 FORMAT  : Format string. Default=`"
-         << format << "`.\n\
+              << format << "`.\n\
 HEADER  : Header string. Default=`"
-         << header << "`.\n\
+              << header << "`.\n\
 SENTINEL: Sentinel character. \n\
 \n\
 Each line of the output will be formatted according to the format string.\
@@ -59,26 +59,32 @@ int main(int argc, char * argv[])
         print_usage(argv[0]);
         return 1;
     }
-    if (argc > 2) { format = argv[2]; }
-    if (argc > 3) { header = argv[3]; }
-    while (cin.getline(line, BUF_SIZE))
+    if (argc > 2)
     {
-        cout << header << endl;
+        format = argv[2];
+    }
+    if (argc > 3)
+    {
+        header = argv[3];
+    }
+    while (std::cin.getline(line, BUF_SIZE))
+    {
+        std::cout << header << std::endl;
         if ('1' == argv[1][0])
         {
             cst_byte_t cst;
-            construct_im(cst, (const char *)line, 1);
-            stringstream ss;
+            construct_im(cst, (char const *)line, 1);
+            std::stringstream ss;
             csXprintf(ss, format, cst, ((argc > 4) ? argv[4][0] : '$'));
             std::string line(ss.str());
-            cout << std::regex_replace(line, std::regex(R"(\$)"), "\\$") << endl;
+            std::cout << std::regex_replace(line, std::regex(R"(\$)"), "\\$") << std::endl;
         }
         else if ('d' == argv[1][0])
         {
             cst_int_t cst;
-            construct_im(cst, (const char *)line, 'd');
-            csXprintf(cout, format, cst, ((argc > 4) ? argv[4][0] : '0'));
+            construct_im(cst, (char const *)line, 'd');
+            csXprintf(std::cout, format, cst, ((argc > 4) ? argv[4][0] : '0'));
         }
-        cout << endl;
+        std::cout << std::endl;
     }
 }
