@@ -1,13 +1,14 @@
 #include <iostream>
 
-#include <sdsl/bit_vectors.hpp>
+#include <sdsl/int_vector.hpp>
+#include <sdsl/rank_support_v.hpp>
 
 using namespace std;
 using namespace sdsl;
 
 int main()
 {
-    bit_vector b = { 0, 1, 0, 1 };
+    bit_vector b = {0, 1, 0, 1};
     rank_support_v<1> b_r1(&b);
     rank_support_v<0> b_r0(&b);
     rank_support_v<10, 2> b_r10(&b);
