@@ -1,5 +1,7 @@
 #include <iostream>
 
+#include <sdsl/construct.hpp>
+#include <sdsl/rrr_vector.hpp>
 #include <sdsl/wavelet_trees.hpp>
 
 using namespace std;
@@ -8,7 +10,7 @@ using namespace sdsl;
 int main()
 {
     wt_huff_int<rrr_vector<63>> wt;
-    construct_im(wt, int_vector<>({ 1981, 1974, 1990, 1974, 2014, 1974 }));
+    construct_im(wt, int_vector<>({1981, 1974, 1990, 1974, 2014, 1974}));
     cout << "wt.sigma : " << wt.sigma << endl;
     cout << wt << endl;
     size_t idx = 5;
