@@ -1,7 +1,9 @@
 #include <algorithm>
 #include <iostream>
 
-#include <sdsl/suffix_arrays.hpp>
+#include <sdsl/csa_wt.hpp>
+#include <sdsl/suffix_array_algorithm.hpp>
+#include <sdsl/wt_huff.hpp>
 
 using namespace std;
 using namespace sdsl;
@@ -14,6 +16,7 @@ int main()
     auto occs = locate(csa, "\n");
     sort(occs.begin(), occs.end());
     auto max_line_length = occs[0];
-    for (size_t i = 1; i < occs.size(); ++i) max_line_length = std::max(max_line_length, occs[i] - occs[i - 1] + 1);
+    for (size_t i = 1; i < occs.size(); ++i)
+        max_line_length = std::max(max_line_length, occs[i] - occs[i - 1] + 1);
     cout << "max line length : " << max_line_length << endl;
 }
