@@ -1,6 +1,6 @@
 #include <iostream>
 
-#include <sdsl/suffix_arrays.hpp>
+#include <sdsl/csa_wt.hpp>
 
 using namespace sdsl;
 using namespace std;
