@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -99,7 +99,7 @@ public:
         /* The current hold directory is cleaned. A simple std::swap is not
          * performed to avoid prolonging the life of the temporary directory.
          */
-        warn_and_clean();
+        clean();
         directory_path = std::exchange(other.directory_path, std::nullopt);
         return *this;
     }
@@ -133,7 +133,7 @@ public:
      */
     ~tmp_directory()
     {
-        warn_and_clean();
+        clean();
     }
     //!\}
 
@@ -157,11 +157,15 @@ public:
         return exists(directory_path.value()) && is_empty(directory_path.value());
     }
 
-    /*!\brief Removes all files from the temporary directory
+private:
+    /*!\brief Warns and cleans if directory is not empty
      */
     void clean()
     {
-        assert(directory_path);
+        if (!directory_path)
+        {
+            return;
+        }
 
         // Deletes all directories recursivly without following symlinks.
         // Function will throw on error.
@@ -169,33 +173,6 @@ public:
         directory_path = std::nullopt;
     }
 
-private:
-    /*!\brief Warns and cleans if directory is not empty
-     */
-    void warn_and_clean()
-    {
-        if (!directory_path)
-        {
-            return;
-        }
-
-        if (!exists(directory_path.value()))
-        {
-            std::cerr << "temporary directory " << directory_path.value()
-                      << " was deleted externally. This is discouraged program behaviour\n";
-            return;
-        }
-        if (!empty())
-        {
-            std::cerr << "temporary directory " << directory_path.value() << " has some files that should be deleted\n";
-            for (auto & p : std::filesystem::recursive_directory_iterator(directory_path.value()))
-            {
-                std::cerr << "- " << p << "\n";
-            }
-        }
-        clean();
-    }
-
 private:
     std::optional<sandboxed_path> directory_path;
 };
