@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -11,6 +11,7 @@
 #include <cstring>
 
 #include <seqan3/alphabet/all.hpp>
+#include <seqan3/test/performance/simd_dna4.hpp>
 #include <seqan3/test/seqan2.hpp>
 
 #if SEQAN3_HAS_SEQAN2
@@ -50,14 +51,20 @@ void to_char(benchmark::State & state)
     std::array<alphabet_t, 256> alphs = create_alphabet_array<alphabet_t, false>();
 
     for (auto _ : state)
+    {
         for (alphabet_t a : alphs)
-            benchmark::DoNotOptimize(seqan3::to_char(a));
+        {
+            char c = seqan3::to_char(a);
+            benchmark::DoNotOptimize(c);
+        }
+    }
 }
 
 /* regular alphabets, sorted by size */
 BENCHMARK_TEMPLATE(to_char, seqan3::gap);
 BENCHMARK_TEMPLATE(to_char, seqan3::dna4);
 BENCHMARK_TEMPLATE(to_char, seqan3::rna4);
+BENCHMARK_TEMPLATE(to_char, seqan3::simd_dna4);
 BENCHMARK_TEMPLATE(to_char, seqan3::dna5);
 BENCHMARK_TEMPLATE(to_char, seqan3::rna5);
 BENCHMARK_TEMPLATE(to_char, seqan3::dna15);
@@ -94,19 +101,24 @@ void to_char_seqan2(benchmark::State & state)
     std::array<alphabet_t, 256> alphs = create_alphabet_array<alphabet_t, true>();
 
     for (auto _ : state)
+    {
         for (alphabet_t a : alphs)
-            benchmark::DoNotOptimize(static_cast<char>(a));
+        {
+            char c = static_cast<char>(a);
+            benchmark::DoNotOptimize(c);
+        }
+    }
 }
 
-BENCHMARK_TEMPLATE(to_char_seqan2, seqan::Dna);
-BENCHMARK_TEMPLATE(to_char_seqan2, seqan::Rna);
-BENCHMARK_TEMPLATE(to_char_seqan2, seqan::Dna5);
-BENCHMARK_TEMPLATE(to_char_seqan2, seqan::Rna5);
-BENCHMARK_TEMPLATE(to_char_seqan2, seqan::Iupac);
-BENCHMARK_TEMPLATE(to_char_seqan2, seqan::AminoAcid);
+BENCHMARK_TEMPLATE(to_char_seqan2, seqan2::Dna);
+BENCHMARK_TEMPLATE(to_char_seqan2, seqan2::Rna);
+BENCHMARK_TEMPLATE(to_char_seqan2, seqan2::Dna5);
+BENCHMARK_TEMPLATE(to_char_seqan2, seqan2::Rna5);
+BENCHMARK_TEMPLATE(to_char_seqan2, seqan2::Iupac);
+BENCHMARK_TEMPLATE(to_char_seqan2, seqan2::AminoAcid);
 
-BENCHMARK_TEMPLATE(to_char_seqan2, seqan::Dna5Q);
-BENCHMARK_TEMPLATE(to_char_seqan2, typename seqan::GappedValueType<seqan::Dna>::Type);
+BENCHMARK_TEMPLATE(to_char_seqan2, seqan2::Dna5Q);
+BENCHMARK_TEMPLATE(to_char_seqan2, typename seqan2::GappedValueType<seqan2::Dna>::Type);
 #endif
 
 BENCHMARK_MAIN();
