@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -40,8 +40,13 @@ template <typename rng_t>
 void sequential_read_impl(benchmark::State & state, rng_t && rng)
 {
     for (auto _ : state)
+    {
         for (auto && outer : rng)
-            benchmark::DoNotOptimize(outer[0].to_rank());
+        {
+            auto rank = outer[0].to_rank();
+            benchmark::DoNotOptimize(rank);
+        }
+    }
 }
 
 template <typename tag_t>
@@ -84,8 +89,13 @@ template <typename rng_t>
 void random_access_impl(benchmark::State & state, rng_t && rng, std::vector<size_t> const & access_positions)
 {
     for (auto _ : state)
+    {
         for (auto pos : access_positions)
-            benchmark::DoNotOptimize(rng[pos][0].to_rank());
+        {
+            auto access = rng[pos][0].to_rank();
+            benchmark::DoNotOptimize(access);
+        }
+    }
 }
 
 template <typename tag_t>
