@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -68,7 +68,10 @@ void read_random(benchmark::State & state)
     for (auto _ : state)
     {
         for (k = 0; k < 10; ++k)
-            benchmark::DoNotOptimize(gap_decorator[access_positions[j + k]]);
+        {
+            auto access = gap_decorator[access_positions[j + k]];
+            benchmark::DoNotOptimize(access);
+        }
         ++j;
         j %= (1 << 10) - 10;
     }
