@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -10,7 +10,6 @@
 #include <seqan3/alphabet/aminoacid/aa27.hpp>
 #include <seqan3/alphabet/nucleotide/dna4.hpp>
 #include <seqan3/alphabet/views/rank_to.hpp>
-#include <seqan3/core/detail/persist_view.hpp>
 #include <seqan3/search/fm_index/all.hpp>
 #include <seqan3/test/performance/sequence_generator.hpp>
 #include <seqan3/test/seqan2.hpp>
@@ -27,10 +26,11 @@ static constexpr size_t seed{0x6126f};
 static void arguments(benchmark::internal::Benchmark * b)
 {
 #ifndef NDEBUG
-    for (int32_t length : {50, 5000})
+    constexpr std::array<int32_t, 2> values{50, 5000};
 #else
-    for (int32_t length : {50, 5000, 50'000})
+    constexpr std::array<int32_t, 3> values{50, 5000, 50'000};
 #endif // NDEBUG
+    for (int32_t length : values)
     {
         if (length > max_length)
             throw std::logic_error{"Increase max_length to at least " + std::to_string(length)};
@@ -99,10 +99,11 @@ void index_benchmark_seqan3(benchmark::State & state)
 #if SEQAN3_HAS_SEQAN2
 struct sequence_store_seqan2
 {
-    seqan::String<seqan::Dna> const dna4_rng{seqan3::test::generate_sequence_seqan2<seqan::Dna>(max_length, 0, seed)};
-    seqan::String<seqan::AminoAcid> const aa27_rng{
-        seqan3::test::generate_sequence_seqan2<seqan::AminoAcid>(max_length, 0, seed)};
-    seqan::String<char> const char_rng{
+    seqan2::String<seqan2::Dna> const dna4_rng{
+        seqan3::test::generate_sequence_seqan2<seqan2::Dna>(max_length, 0, seed)};
+    seqan2::String<seqan2::AminoAcid> const aa27_rng{
+        seqan3::test::generate_sequence_seqan2<seqan2::AminoAcid>(max_length, 0, seed)};
+    seqan2::String<char> const char_rng{
         []()
         {
             std::vector<uint8_t> const ranks{
@@ -117,9 +118,9 @@ sequence_store_seqan2 store2{};
 template <typename rng_t>
 constexpr size_t seqan_dimension_v()
 {
-    if (seqan3::detail::is_type_specialisation_of_v<rng_t, seqan::String>)
+    if (seqan3::detail::is_type_specialisation_of_v<rng_t, seqan2::String>)
         return 1;
-    if (seqan3::detail::is_type_specialisation_of_v<rng_t, seqan::StringSet>)
+    if (seqan3::detail::is_type_specialisation_of_v<rng_t, seqan2::StringSet>)
         return 2;
     return 0;
 }
@@ -128,29 +129,30 @@ template <tag index_tag, typename rng_t>
 void index_benchmark_seqan2(benchmark::State & state)
 {
     constexpr size_t dimension = seqan_dimension_v<rng_t>();
-    static_assert(dimension != 0, "Use seqan::String or seqan::StringSet for SeqAn2 index benchmarks!");
+    static_assert(dimension != 0, "Use seqan2::String or seqan2::StringSet for SeqAn2 index benchmarks!");
 
-    // Calling std::ranges::range_value_t twice on seqan::String<char> is not valid.
+    // Calling std::ranges::range_value_t twice on seqan2::String<char> is not valid.
     using alphabet_t = seqan3::detail::lazy_conditional_t<
         dimension == 1,
         std::ranges::range_value_t<rng_t>,
         seqan3::detail::lazy<std::ranges::range_value_t, std::ranges::range_value_t<rng_t>>>;
 
     using inner_rng_t = std::conditional_t<dimension == 1, rng_t, std::ranges::range_value_t<rng_t>>;
-    using index_cfg = seqan::FastFMIndexConfig<void, uint64_t>;
-    using index_t = std::conditional_t<index_tag == tag::fm_index,
-                                       seqan::Index<rng_t, seqan::FMIndex<void, index_cfg>>,
-                                       seqan::Index<rng_t, seqan::BidirectionalIndex<seqan::FMIndex<void, index_cfg>>>>;
+    using index_cfg = seqan2::FastFMIndexConfig<void, uint64_t>;
+    using index_t =
+        std::conditional_t<index_tag == tag::fm_index,
+                           seqan2::Index<rng_t, seqan2::FMIndex<void, index_cfg>>,
+                           seqan2::Index<rng_t, seqan2::BidirectionalIndex<seqan2::FMIndex<void, index_cfg>>>>;
 
     rng_t sequence;
     inner_rng_t inner_sequence;
 
-    if constexpr (std::same_as<alphabet_t, seqan::Dna>)
-        inner_sequence = seqan::prefix(store2.dna4_rng, state.range(0));
-    else if constexpr (std::same_as<alphabet_t, seqan::AminoAcid>)
-        inner_sequence = seqan::prefix(store2.aa27_rng, state.range(0));
+    if constexpr (std::same_as<alphabet_t, seqan2::Dna>)
+        inner_sequence = seqan2::prefix(store2.dna4_rng, state.range(0));
+    else if constexpr (std::same_as<alphabet_t, seqan2::AminoAcid>)
+        inner_sequence = seqan2::prefix(store2.aa27_rng, state.range(0));
     else
-        inner_sequence = seqan::prefix(store2.char_rng, state.range(0));
+        inner_sequence = seqan2::prefix(store2.char_rng, state.range(0));
 
     if constexpr (dimension == 1)
     {
@@ -159,13 +161,13 @@ void index_benchmark_seqan2(benchmark::State & state)
     else
     {
         for (int32_t i = 0; i < state.range(1); ++i)
-            seqan::appendValue(sequence, inner_sequence);
+            seqan2::appendValue(sequence, inner_sequence);
     }
 
     for (auto _ : state)
     {
         index_t index{sequence};
-        seqan::indexCreate(index, seqan::FibreSALF());
+        seqan2::indexCreate(index, seqan2::FibreSALF());
     }
 }
 #endif // SEQAN3_HAS_SEQAN2
@@ -190,20 +192,20 @@ BENCHMARK_TEMPLATE(index_benchmark_seqan3, tag::bi_fm_index, two_dimensional<std
 
 #if SEQAN3_HAS_SEQAN2
 template <typename t>
-using one_dimensional2 = seqan::String<t>;
+using one_dimensional2 = seqan2::String<t>;
 template <typename t>
-using two_dimensional2 = seqan::StringSet<seqan::String<t>>;
+using two_dimensional2 = seqan2::StringSet<seqan2::String<t>>;
 
-BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::fm_index, one_dimensional2<seqan::Dna>)->Apply(arguments);
-BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::fm_index, two_dimensional2<seqan::Dna>)->Apply(arguments);
-BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::fm_index, one_dimensional2<seqan::AminoAcid>)->Apply(arguments);
-BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::fm_index, two_dimensional2<seqan::AminoAcid>)->Apply(arguments);
+BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::fm_index, one_dimensional2<seqan2::Dna>)->Apply(arguments);
+BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::fm_index, two_dimensional2<seqan2::Dna>)->Apply(arguments);
+BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::fm_index, one_dimensional2<seqan2::AminoAcid>)->Apply(arguments);
+BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::fm_index, two_dimensional2<seqan2::AminoAcid>)->Apply(arguments);
 BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::fm_index, one_dimensional2<char>)->Apply(arguments);
 BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::fm_index, two_dimensional2<char>)->Apply(arguments);
-BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::bi_fm_index, one_dimensional2<seqan::Dna>)->Apply(arguments);
-BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::bi_fm_index, two_dimensional2<seqan::Dna>)->Apply(arguments);
-BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::bi_fm_index, one_dimensional2<seqan::AminoAcid>)->Apply(arguments);
-BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::bi_fm_index, two_dimensional2<seqan::AminoAcid>)->Apply(arguments);
+BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::bi_fm_index, one_dimensional2<seqan2::Dna>)->Apply(arguments);
+BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::bi_fm_index, two_dimensional2<seqan2::Dna>)->Apply(arguments);
+BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::bi_fm_index, one_dimensional2<seqan2::AminoAcid>)->Apply(arguments);
+BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::bi_fm_index, two_dimensional2<seqan2::AminoAcid>)->Apply(arguments);
 BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::bi_fm_index, one_dimensional2<char>)->Apply(arguments);
 BENCHMARK_TEMPLATE(index_benchmark_seqan2, tag::bi_fm_index, two_dimensional2<char>)->Apply(arguments);
 #endif // SEQAN3_HAS_SEQAN2
