@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -19,11 +19,20 @@ static void is_power_of_two_popcount(benchmark::State & state)
     {
         n = std::rand();
         if constexpr (std::is_same_v<size_type, unsigned long long>)
-            benchmark::DoNotOptimize(__builtin_popcountll(n) == 1);
+        {
+            bool result = __builtin_popcountll(n) == 1;
+            benchmark::DoNotOptimize(result);
+        }
         else if constexpr (std::is_same_v<size_type, unsigned long>)
-            benchmark::DoNotOptimize(__builtin_popcountl(n) == 1);
+        {
+            bool result = __builtin_popcountl(n) == 1;
+            benchmark::DoNotOptimize(result);
+        }
         else if constexpr (std::is_same_v<size_type, unsigned>)
-            benchmark::DoNotOptimize(__builtin_popcount(n) == 1);
+        {
+            bool result = __builtin_popcount(n) == 1;
+            benchmark::DoNotOptimize(result);
+        }
         else
             static_assert(std::is_same_v<size_type, void>, "FAILED");
     }
@@ -39,7 +48,8 @@ static void is_power_of_two_arithmetic(benchmark::State & state)
     for (auto _ : state)
     {
         n = std::rand();
-        benchmark::DoNotOptimize(n > 0 && (n & (n - 1)) == 0);
+        bool result = n > 0 && (n & (n - 1)) == 0;
+        benchmark::DoNotOptimize(result);
     }
 }
 BENCHMARK(is_power_of_two_arithmetic);
@@ -51,7 +61,8 @@ static void is_power_of_two_std(benchmark::State & state)
     for (auto _ : state)
     {
         n = std::rand();
-        benchmark::DoNotOptimize(std::has_single_bit(n));
+        bool result = std::has_single_bit(n);
+        benchmark::DoNotOptimize(result);
     }
 }
 BENCHMARK(is_power_of_two_std);
@@ -63,7 +74,8 @@ static void next_power_of_two_std(benchmark::State & state)
     for (auto _ : state)
     {
         n = std::rand();
-        benchmark::DoNotOptimize(std::bit_ceil(n));
+        bool result = std::bit_ceil(n);
+        benchmark::DoNotOptimize(result);
     }
 }
 BENCHMARK(next_power_of_two_std);
