@@ -9,9 +9,9 @@ using namespace seqan3::literals;
 
 int main()
 {
-    auto min_cfg = seqan3::align_cfg::method_global{} |
-                   seqan3::align_cfg::scoring_scheme{seqan3::nucleotide_scoring_scheme{seqan3::match_score{4},
-                                                                                       seqan3::mismatch_score{-5}}};
+    auto min_cfg = seqan3::align_cfg::method_global{}
+                 | seqan3::align_cfg::scoring_scheme{
+                     seqan3::nucleotide_scoring_scheme{seqan3::match_score{4}, seqan3::mismatch_score{-5}}};
 
     auto seq1 = "ACGT"_dna4;
     auto seq2 = "ACCT"_dna4;
