@@ -7,7 +7,7 @@
 
 int main()
 {
-    using seqan3::operator""_dna5;
+    using namespace seqan3::literals;
 
     seqan3::sequence_file_output fout{std::ostringstream{}, seqan3::format_fasta{}};
 
@@ -18,8 +18,8 @@ int main()
 
         // ...
 
-        fout.emplace_back(seq, id);          // as individual variables
+        fout.emplace_back(seq, id); // as individual variables
         // or:
-        fout.push_back(std::tie(seq, id));   // as a tuple
+        fout.push_back(std::tie(seq, id)); // as a tuple
     }
 }
