@@ -1,5 +1,6 @@
+#include <filesystem>
+
 #include <seqan3/io/structure_file/output.hpp>
-#include <seqan3/std/filesystem>
 
 int main()
 {
