@@ -1,4 +1,4 @@
-#include <seqan3/std/ranges>                            // for std::views::reverse
+#include <ranges> // for std::views::reverse
 #include <string>
 
 #include <seqan3/core/debug_stream.hpp>                 // for debug_stream
@@ -11,7 +11,7 @@ int main()
     // regular usage
     std::string vec{"foo\nbar"};
     auto v = vec | seqan3::detail::take_until(seqan3::is_char<'\n'>); // or use a lambda
-    seqan3::debug_stream << v << '\n'; // "foo"
+    seqan3::debug_stream << v << '\n';                                // "foo"
 
     auto v2 = vec | std::views::reverse | seqan3::detail::take_until(seqan3::is_char<'\n'>);
     seqan3::debug_stream << v2 << '\n'; // "rab"
@@ -20,6 +20,6 @@ int main()
     std::string vec2{"foo      bar"}; // ← multiple spaces
     auto vin = vec2 | seqan3::views::single_pass_input;
     auto v3 = vin | seqan3::detail::take_until_and_consume(seqan3::is_blank);
-    seqan3::debug_stream << v3 << '\n'; // "foo"
+    seqan3::debug_stream << v3 << '\n';                       // "foo"
     seqan3::debug_stream << *std::ranges::begin(vin) << '\n'; // "b", the spaces where skipped
 }
