@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -219,6 +219,12 @@ struct debug_matrix_traits<seqan3::detail::debug_matrix<matrix_t, first_sequence
     using second_sequence_type = second_sequence_t;
 };
 
+#pragma GCC diagnostic push
+// Ignore bogus warnings in fortified gcc13 build
+#if defined(_FORTIFY_SOURCE) && (_FORTIFY_SOURCE == 2) // _FORTIFY_SOURCE=2 may cause conforming programs to fail
+#    pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
+#endif
+
 TEST_F(debug_matrix_test, matrix_concept)
 {
     EXPECT_TRUE((seqan3::detail::matrix<seqan3::detail::row_wise_matrix<int>>));
@@ -620,3 +626,5 @@ TEST_F(trace_matrix_test, transpose_matrix_rvalue)
 
     EXPECT_EQ(transpose_matrix, transposed_trace_matrix);
 }
+
+#pragma GCC diagnostic pop
