@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -20,97 +20,75 @@ struct debug_matrix_stream_test : public ::testing::Test
     std::vector<seqan3::dna4> sequence1 = "AACACGTTAACCGGTT"_dna4;
     std::vector<seqan3::dna4> sequence2 = "ACGTACGT"_dna4;
 
-    seqan3::detail::row_wise_matrix<std::optional<int>> score_matrix
-    {
-        seqan3::detail::number_rows{9u}, seqan3::detail::number_cols{17u}, std::vector<std::optional<int>>
-        {
-            0,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13, 14, 15, 16,
-            1,  0,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13, 14, 15,
-            2,  1,  1,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13, 14,
-            3,  2,  2,  2,  2,  3,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13,
-            4,  3,  3,  3,  3,  3,  4,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12,
-            5,  4,  3,  4,  3,  4,  4,  4,  4,  4,  5,  6,  7,  8,  9, 10, 11,
-            6,  5,  4,  3,  4,  3,  4,  5,  5,  5,  5,  5,  6,  7,  8,  9, 10,
-            7,  6,  5,  4,  4,  4,  3,  4,  5,  6,  6,  6,  6,  6,  7,  8,  9,
-            inf,7,  6,  5,  5,  5,  4,  3,  4,  5,  6,  7,  7,  7,  7,  7,  8
-        }
-    };
+    seqan3::detail::row_wise_matrix<std::optional<int>> score_matrix{
+        seqan3::detail::number_rows{9u},
+        seqan3::detail::number_cols{17u},
+        std::vector<std::optional<int>>{
+            0, 1, 2,  3,  4,  5,  6,   7,  8, 9, 10, 11, 12, 13, 14, 15, 16, 1, 0, 1, 2,  3,  4,  5,  6,  7,
+            8, 9, 10, 11, 12, 13, 14,  15, 2, 1, 1,  1,  2,  3,  4,  5,  6,  7, 8, 9, 10, 11, 12, 13, 14, 3,
+            2, 2, 2,  2,  3,  3,  4,   5,  6, 7, 8,  9,  10, 11, 12, 13, 4,  3, 3, 3, 3,  3,  4,  3,  4,  5,
+            6, 7, 8,  9,  10, 11, 12,  5,  4, 3, 4,  3,  4,  4,  4,  4,  4,  5, 6, 7, 8,  9,  10, 11, 6,  5,
+            4, 3, 4,  3,  4,  5,  5,   5,  5, 5, 6,  7,  8,  9,  10, 7,  6,  5, 4, 4, 4,  3,  4,  5,  6,  6,
+            6, 6, 6,  7,  8,  9,  inf, 7,  6, 5, 5,  5,  4,  3,  4,  5,  6,  7, 7, 7, 7,  7,  8}};
 
-    seqan3::detail::trace_directions N{},
-        D{seqan3::detail::trace_directions::diagonal},
-        L{seqan3::detail::trace_directions::left},
-        U{seqan3::detail::trace_directions::up},
-        DL{D|L}, DU{D|U}, UL{U|L}, DUL{D|U|L};
+    seqan3::detail::trace_directions N{}, D{seqan3::detail::trace_directions::diagonal},
+        L{seqan3::detail::trace_directions::left}, U{seqan3::detail::trace_directions::up}, DL{D | L}, DU{D | U},
+        UL{U | L}, DUL{D | U | L};
 
-    seqan3::detail::row_wise_matrix<detail::trace_directions> trace_matrix
-    {
-        seqan3::detail::number_rows{9u}, seqan3::detail::number_cols{17u}, std::vector
-        {
-            N,  L,  L,  L,  L,  L,  L,  L,  L,  L,  L,  L,  L,  L,  L,  L,  L,
-            U,  D,  DL, L,  DL, L,  L,  L,  L,  DL, DL, L,  L,  L,  L,  L,  L,
-            U,  U,  D,  D,  L,  DL, L,  L,  L,  L,  L,  DL, DL, L,  L,  L,  L,
-            U,  U,  DU, DU, D,  DL, D,  L,  L,  L,  L,  L,  L,  DL, DL, L,  L,
-            U,  U,  DU, DU, DU, D,  DUL,D,  DL, L,  L,  L,  L,  L,  L,  DL, DL,
-            U,  DU, D,  DUL,D,  DUL,D,  U,  D,  D,  DL, L,  L,  L,  L,  L,  L,
-            U,  U,  U,  D,  UL, D,  L,  DUL,DU, DU, D,  D,  DL, L,  L,  L,  L,
-            U,  U,  U,  U,  D,  U,  D,  L,  L,  DUL,DU, DU, D,  D,  DL, L,  L,
-            N,  U,  U,  U,  DU, DU, U,  D,  DL, L,  L,  DUL,DU, DU, D,  D,  DL
-        }
-    };
+    seqan3::detail::row_wise_matrix<detail::trace_directions> trace_matrix{
+        seqan3::detail::number_rows{9u},
+        seqan3::detail::number_cols{17u},
+        std::vector{N,   L,  L,   L, L,  L,  L,  L,  L,   L,  L,  L, L,  L, L, L,   L,  U,  D,   DL, L,  DL,
+                    L,   L,  L,   L, DL, DL, L,  L,  L,   L,  L,  L, U,  U, D, D,   L,  DL, L,   L,  L,  L,
+                    L,   DL, DL,  L, L,  L,  L,  U,  U,   DU, DU, D, DL, D, L, L,   L,  L,  L,   L,  DL, DL,
+                    L,   L,  U,   U, DU, DU, DU, D,  DUL, D,  DL, L, L,  L, L, L,   L,  DL, DL,  U,  DU, D,
+                    DUL, D,  DUL, D, U,  D,  D,  DL, L,   L,  L,  L, L,  L, U, U,   U,  D,  UL,  D,  L,  DUL,
+                    DU,  DU, D,   D, DL, L,  L,  L,  L,   U,  U,  U, U,  D, U, D,   L,  L,  DUL, DU, DU, D,
+                    D,   DL, L,   L, N,  U,  U,  U,  DU,  DU, U,  D, DL, L, L, DUL, DU, DU, D,   D,  DL}};
 
-    std::string score_matrix_ascii
-    {
-        " ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;\n"
-        " ;0 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;15;16;\n"
-        " ;1 ;0 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;15;\n"
-        " ;2 ;1 ;1 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;\n"
-        " ;3 ;2 ;2 ;2 ;2 ;3 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;\n"
-        " ;4 ;3 ;3 ;3 ;3 ;3 ;4 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;\n"
-        " ;5 ;4 ;3 ;4 ;3 ;4 ;4 ;4 ;4 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;\n"
-        " ;6 ;5 ;4 ;3 ;4 ;3 ;4 ;5 ;5 ;5 ;5 ;5 ;6 ;7 ;8 ;9 ;10;\n"
-        " ;7 ;6 ;5 ;4 ;4 ;4 ;3 ;4 ;5 ;6 ;6 ;6 ;6 ;6 ;7 ;8 ;9 ;\n"
-        " ;  ;7 ;6 ;5 ;5 ;5 ;4 ;3 ;4 ;5 ;6 ;7 ;7 ;7 ;7 ;7 ;8 ;\n"
-    };
+    std::string score_matrix_ascii{" ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;  ;\n"
+                                   " ;0 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;15;16;\n"
+                                   " ;1 ;0 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;15;\n"
+                                   " ;2 ;1 ;1 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;\n"
+                                   " ;3 ;2 ;2 ;2 ;2 ;3 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;\n"
+                                   " ;4 ;3 ;3 ;3 ;3 ;3 ;4 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;\n"
+                                   " ;5 ;4 ;3 ;4 ;3 ;4 ;4 ;4 ;4 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;\n"
+                                   " ;6 ;5 ;4 ;3 ;4 ;3 ;4 ;5 ;5 ;5 ;5 ;5 ;6 ;7 ;8 ;9 ;10;\n"
+                                   " ;7 ;6 ;5 ;4 ;4 ;4 ;3 ;4 ;5 ;6 ;6 ;6 ;6 ;6 ;7 ;8 ;9 ;\n"
+                                   " ;  ;7 ;6 ;5 ;5 ;5 ;4 ;3 ;4 ;5 ;6 ;7 ;7 ;7 ;7 ;7 ;8 ;\n"};
 
-    std::string score_matrix_ascii_with_sequences
-    {
-        " ;  ;A ;A ;C ;A ;C ;G ;T ;T ;A ;A ;C ;C ;G ;G ;T ;T ;\n"
-        " ;0 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;15;16;\n"
-        "A;1 ;0 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;15;\n"
-        "C;2 ;1 ;1 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;\n"
-        "G;3 ;2 ;2 ;2 ;2 ;3 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;\n"
-        "T;4 ;3 ;3 ;3 ;3 ;3 ;4 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;\n"
-        "A;5 ;4 ;3 ;4 ;3 ;4 ;4 ;4 ;4 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;\n"
-        "C;6 ;5 ;4 ;3 ;4 ;3 ;4 ;5 ;5 ;5 ;5 ;5 ;6 ;7 ;8 ;9 ;10;\n"
-        "G;7 ;6 ;5 ;4 ;4 ;4 ;3 ;4 ;5 ;6 ;6 ;6 ;6 ;6 ;7 ;8 ;9 ;\n"
-        "T;  ;7 ;6 ;5 ;5 ;5 ;4 ;3 ;4 ;5 ;6 ;7 ;7 ;7 ;7 ;7 ;8 ;\n"
-    };
+    std::string score_matrix_ascii_with_sequences{" ;  ;A ;A ;C ;A ;C ;G ;T ;T ;A ;A ;C ;C ;G ;G ;T ;T ;\n"
+                                                  " ;0 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;15;16;\n"
+                                                  "A;1 ;0 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;15;\n"
+                                                  "C;2 ;1 ;1 ;1 ;2 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;14;\n"
+                                                  "G;3 ;2 ;2 ;2 ;2 ;3 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;13;\n"
+                                                  "T;4 ;3 ;3 ;3 ;3 ;3 ;4 ;3 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;12;\n"
+                                                  "A;5 ;4 ;3 ;4 ;3 ;4 ;4 ;4 ;4 ;4 ;5 ;6 ;7 ;8 ;9 ;10;11;\n"
+                                                  "C;6 ;5 ;4 ;3 ;4 ;3 ;4 ;5 ;5 ;5 ;5 ;5 ;6 ;7 ;8 ;9 ;10;\n"
+                                                  "G;7 ;6 ;5 ;4 ;4 ;4 ;3 ;4 ;5 ;6 ;6 ;6 ;6 ;6 ;7 ;8 ;9 ;\n"
+                                                  "T;  ;7 ;6 ;5 ;5 ;5 ;4 ;3 ;4 ;5 ;6 ;7 ;7 ;7 ;7 ;7 ;8 ;\n"};
 
-    std::string score_matrix_unicode
-    {
-        " ║ε ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║\n"
-        " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
-        "ε║0 ║1 ║2 ║3 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║12║13║14║15║16║\n"
-        " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
-        " ║1 ║0 ║1 ║2 ║3 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║12║13║14║15║\n"
-        " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
-        " ║2 ║1 ║1 ║1 ║2 ║3 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║12║13║14║\n"
-        " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
-        " ║3 ║2 ║2 ║2 ║2 ║3 ║3 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║12║13║\n"
-        " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
-        " ║4 ║3 ║3 ║3 ║3 ║3 ║4 ║3 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║12║\n"
-        " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
-        " ║5 ║4 ║3 ║4 ║3 ║4 ║4 ║4 ║4 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║\n"
-        " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
-        " ║6 ║5 ║4 ║3 ║4 ║3 ║4 ║5 ║5 ║5 ║5 ║5 ║6 ║7 ║8 ║9 ║10║\n"
-        " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
-        " ║7 ║6 ║5 ║4 ║4 ║4 ║3 ║4 ║5 ║6 ║6 ║6 ║6 ║6 ║7 ║8 ║9 ║\n"
-        " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
-        " ║∞ ║7 ║6 ║5 ║5 ║5 ║4 ║3 ║4 ║5 ║6 ║7 ║7 ║7 ║7 ║7 ║8 ║\n"
-    };
+    std::string score_matrix_unicode{" ║ε ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║  ║\n"
+                                     " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
+                                     "ε║0 ║1 ║2 ║3 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║12║13║14║15║16║\n"
+                                     " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
+                                     " ║1 ║0 ║1 ║2 ║3 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║12║13║14║15║\n"
+                                     " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
+                                     " ║2 ║1 ║1 ║1 ║2 ║3 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║12║13║14║\n"
+                                     " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
+                                     " ║3 ║2 ║2 ║2 ║2 ║3 ║3 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║12║13║\n"
+                                     " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
+                                     " ║4 ║3 ║3 ║3 ║3 ║3 ║4 ║3 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║12║\n"
+                                     " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
+                                     " ║5 ║4 ║3 ║4 ║3 ║4 ║4 ║4 ║4 ║4 ║5 ║6 ║7 ║8 ║9 ║10║11║\n"
+                                     " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
+                                     " ║6 ║5 ║4 ║3 ║4 ║3 ║4 ║5 ║5 ║5 ║5 ║5 ║6 ║7 ║8 ║9 ║10║\n"
+                                     " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
+                                     " ║7 ║6 ║5 ║4 ║4 ║4 ║3 ║4 ║5 ║6 ║6 ║6 ║6 ║6 ║7 ║8 ║9 ║\n"
+                                     " ╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬══╬\n"
+                                     " ║∞ ║7 ║6 ║5 ║5 ║5 ║4 ║3 ║4 ║5 ║6 ║7 ║7 ║7 ║7 ║7 ║8 ║\n"};
 
-    std::string score_matrix_unicode_with_sequences
-    {
+    std::string score_matrix_unicode_with_sequences{
         " ║ε   ║A   ║A   ║C   ║A   ║C   ║G   ║T   ║T   ║A   ║A   ║C   ║C   ║G   ║G   ║T   ║T   ║\n"
         " ╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬\n"
         "ε║0   ║1   ║2   ║3   ║4   ║5   ║6   ║7   ║8   ║9   ║10  ║11  ║12  ║13  ║14  ║15  ║16  ║\n"
@@ -129,11 +107,9 @@ struct debug_matrix_stream_test : public ::testing::Test
         " ╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬\n"
         "G║7   ║6   ║5   ║4   ║4   ║4   ║3   ║4   ║5   ║6   ║6   ║6   ║6   ║6   ║7   ║8   ║9   ║\n"
         " ╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬\n"
-        "T║∞   ║7   ║6   ║5   ║5   ║5   ║4   ║3   ║4   ║5   ║6   ║7   ║7   ║7   ║7   ║7   ║8   ║\n"
-    };
+        "T║∞   ║7   ║6   ║5   ║5   ║5   ║4   ║3   ║4   ║5   ║6   ║7   ║7   ║7   ║7   ║7   ║8   ║\n"};
 
-    std::string trace_matrix_ascii
-    {
+    std::string trace_matrix_ascii{
         " ;    ;    ;    ;    ;    ;    ;    ;    ;    ;    ;    ;    ;    ;    ;    ;    ;    ;\n"
         " ;N   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;\n"
         " ;u   ;D   ;Dl  ;l   ;Dl  ;l   ;l   ;l   ;l   ;Dl  ;Dl  ;l   ;l   ;l   ;l   ;l   ;l   ;\n"
@@ -143,11 +119,9 @@ struct debug_matrix_stream_test : public ::testing::Test
         " ;u   ;Du  ;D   ;Dul ;D   ;Dul ;D   ;u   ;D   ;D   ;Dl  ;l   ;l   ;l   ;l   ;l   ;l   ;\n"
         " ;u   ;u   ;u   ;D   ;ul  ;D   ;l   ;Dul ;Du  ;Du  ;D   ;D   ;Dl  ;l   ;l   ;l   ;l   ;\n"
         " ;u   ;u   ;u   ;u   ;D   ;u   ;D   ;l   ;l   ;Dul ;Du  ;Du  ;D   ;D   ;Dl  ;l   ;l   ;\n"
-        " ;N   ;u   ;u   ;u   ;Du  ;Du  ;u   ;D   ;Dl  ;l   ;l   ;Dul ;Du  ;Du  ;D   ;D   ;Dl  ;\n"
-    };
+        " ;N   ;u   ;u   ;u   ;Du  ;Du  ;u   ;D   ;Dl  ;l   ;l   ;Dul ;Du  ;Du  ;D   ;D   ;Dl  ;\n"};
 
-    std::string trace_matrix_ascii_with_sequences
-    {
+    std::string trace_matrix_ascii_with_sequences{
         " ;    ;A   ;A   ;C   ;A   ;C   ;G   ;T   ;T   ;A   ;A   ;C   ;C   ;G   ;G   ;T   ;T   ;\n"
         " ;N   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;l   ;\n"
         "A;u   ;D   ;Dl  ;l   ;Dl  ;l   ;l   ;l   ;l   ;Dl  ;Dl  ;l   ;l   ;l   ;l   ;l   ;l   ;\n"
@@ -157,34 +131,29 @@ struct debug_matrix_stream_test : public ::testing::Test
         "A;u   ;Du  ;D   ;Dul ;D   ;Dul ;D   ;u   ;D   ;D   ;Dl  ;l   ;l   ;l   ;l   ;l   ;l   ;\n"
         "C;u   ;u   ;u   ;D   ;ul  ;D   ;l   ;Dul ;Du  ;Du  ;D   ;D   ;Dl  ;l   ;l   ;l   ;l   ;\n"
         "G;u   ;u   ;u   ;u   ;D   ;u   ;D   ;l   ;l   ;Dul ;Du  ;Du  ;D   ;D   ;Dl  ;l   ;l   ;\n"
-        "T;N   ;u   ;u   ;u   ;Du  ;Du  ;u   ;D   ;Dl  ;l   ;l   ;Dul ;Du  ;Du  ;D   ;D   ;Dl  ;\n"
-    };
+        "T;N   ;u   ;u   ;u   ;Du  ;Du  ;u   ;D   ;Dl  ;l   ;l   ;Dul ;Du  ;Du  ;D   ;D   ;Dl  ;\n"};
 
-    std::string trace_matrix_unicode
-    {
-        " ║ε  ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║\n"
-        " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
-        "ε║↺  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║\n"
-        " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
-        " ║⇡  ║↖  ║↖⇠ ║⇠  ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║↖⇠ ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║\n"
-        " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
-        " ║⇡  ║⇡  ║↖  ║↖  ║⇠  ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║↖⇠ ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║\n"
-        " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
-        " ║⇡  ║⇡  ║↖⇡ ║↖⇡ ║↖  ║↖⇠ ║↖  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║↖⇠ ║↖⇠ ║⇠  ║⇠  ║\n"
-        " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
-        " ║⇡  ║⇡  ║↖⇡ ║↖⇡ ║↖⇡ ║↖  ║↖⇡⇠║↖  ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║↖⇠ ║↖⇠ ║\n"
-        " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
-        " ║⇡  ║↖⇡ ║↖  ║↖⇡⇠║↖  ║↖⇡⇠║↖  ║⇡  ║↖  ║↖  ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║\n"
-        " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
-        " ║⇡  ║⇡  ║⇡  ║↖  ║⇡⇠ ║↖  ║⇠  ║↖⇡⇠║↖⇡ ║↖⇡ ║↖  ║↖  ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║\n"
-        " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
-        " ║⇡  ║⇡  ║⇡  ║⇡  ║↖  ║⇡  ║↖  ║⇠  ║⇠  ║↖⇡⇠║↖⇡ ║↖⇡ ║↖  ║↖  ║↖⇠ ║⇠  ║⇠  ║\n"
-        " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
-        " ║↺  ║⇡  ║⇡  ║⇡  ║↖⇡ ║↖⇡ ║⇡  ║↖  ║↖⇠ ║⇠  ║⇠  ║↖⇡⇠║↖⇡ ║↖⇡ ║↖  ║↖  ║↖⇠ ║\n"
-    };
+    std::string trace_matrix_unicode{" ║ε  ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║   ║\n"
+                                     " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
+                                     "ε║↺  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║\n"
+                                     " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
+                                     " ║⇡  ║↖  ║↖⇠ ║⇠  ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║↖⇠ ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║\n"
+                                     " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
+                                     " ║⇡  ║⇡  ║↖  ║↖  ║⇠  ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║↖⇠ ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║\n"
+                                     " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
+                                     " ║⇡  ║⇡  ║↖⇡ ║↖⇡ ║↖  ║↖⇠ ║↖  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║↖⇠ ║↖⇠ ║⇠  ║⇠  ║\n"
+                                     " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
+                                     " ║⇡  ║⇡  ║↖⇡ ║↖⇡ ║↖⇡ ║↖  ║↖⇡⇠║↖  ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║↖⇠ ║↖⇠ ║\n"
+                                     " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
+                                     " ║⇡  ║↖⇡ ║↖  ║↖⇡⇠║↖  ║↖⇡⇠║↖  ║⇡  ║↖  ║↖  ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║⇠  ║\n"
+                                     " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
+                                     " ║⇡  ║⇡  ║⇡  ║↖  ║⇡⇠ ║↖  ║⇠  ║↖⇡⇠║↖⇡ ║↖⇡ ║↖  ║↖  ║↖⇠ ║⇠  ║⇠  ║⇠  ║⇠  ║\n"
+                                     " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
+                                     " ║⇡  ║⇡  ║⇡  ║⇡  ║↖  ║⇡  ║↖  ║⇠  ║⇠  ║↖⇡⇠║↖⇡ ║↖⇡ ║↖  ║↖  ║↖⇠ ║⇠  ║⇠  ║\n"
+                                     " ╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬═══╬\n"
+                                     " ║↺  ║⇡  ║⇡  ║⇡  ║↖⇡ ║↖⇡ ║⇡  ║↖  ║↖⇠ ║⇠  ║⇠  ║↖⇡⇠║↖⇡ ║↖⇡ ║↖  ║↖  ║↖⇠ ║\n"};
 
-    std::string trace_matrix_unicode_with_sequences
-    {
+    std::string trace_matrix_unicode_with_sequences{
         " ║ε   ║A   ║A   ║C   ║A   ║C   ║G   ║T   ║T   ║A   ║A   ║C   ║C   ║G   ║G   ║T   ║T   ║\n"
         " ╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬\n"
         "ε║↺   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║⇠   ║\n"
@@ -203,8 +172,7 @@ struct debug_matrix_stream_test : public ::testing::Test
         " ╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬\n"
         "G║⇡   ║⇡   ║⇡   ║⇡   ║↖   ║⇡   ║↖   ║⇠   ║⇠   ║↖⇡⇠ ║↖⇡  ║↖⇡  ║↖   ║↖   ║↖⇠  ║⇠   ║⇠   ║\n"
         " ╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬════╬\n"
-        "T║↺   ║⇡   ║⇡   ║⇡   ║↖⇡  ║↖⇡  ║⇡   ║↖   ║↖⇠  ║⇠   ║⇠   ║↖⇡⇠ ║↖⇡  ║↖⇡  ║↖   ║↖   ║↖⇠  ║\n"
-    };
+        "T║↺   ║⇡   ║⇡   ║⇡   ║↖⇡  ║↖⇡  ║⇡   ║↖   ║↖⇠  ║⇠   ║⇠   ║↖⇡⇠ ║↖⇡  ║↖⇡  ║↖   ║↖   ║↖⇠  ║\n"};
 
     struct debug_matrix_access : public debug_matrix<row_wise_matrix<int>>
     {
