@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -19,8 +19,8 @@ static constexpr auto N = seqan3::detail::trace_directions::none;
 static constexpr auto D = seqan3::detail::trace_directions::diagonal;
 static constexpr auto u = seqan3::detail::trace_directions::up;
 static constexpr auto l = seqan3::detail::trace_directions::left;
-static constexpr auto U = seqan3::detail::trace_directions::up_open;
-static constexpr auto L = seqan3::detail::trace_directions::left_open;
+static constexpr auto U = seqan3::detail::trace_directions::carry_up_open;
+static constexpr auto L = seqan3::detail::trace_directions::carry_left_open;
 static constexpr auto DU = D | U;
 static constexpr auto UL = U | L;
 static constexpr auto DL = D | L;
