@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -8,17 +8,16 @@
 #include <gtest/gtest.h>
 
 #include <seqan3/alphabet/gap/gapped.hpp>
+#include <seqan3/alphabet/hash.hpp>
 #include <seqan3/alphabet/nucleotide/dna4.hpp>
 #include <seqan3/alphabet/quality/phred42.hpp>
 #include <seqan3/alphabet/quality/qualified.hpp>
-#include <seqan3/alphabet/hash.hpp>
 
 template <typename T>
 using alphabet_hashing = ::testing::Test;
 
-using test_types = ::testing::Types<seqan3::dna4,
-                                    seqan3::qualified<seqan3::dna4, seqan3::phred42>,
-                                    seqan3::gapped<seqan3::dna4>>;
+using test_types =
+    ::testing::Types<seqan3::dna4, seqan3::qualified<seqan3::dna4, seqan3::phred42>, seqan3::gapped<seqan3::dna4>>;
 
 TYPED_TEST_SUITE(alphabet_hashing, test_types, );
 
@@ -29,7 +28,7 @@ TYPED_TEST(alphabet_hashing, hash)
         std::hash<TypeParam> h{};
         if constexpr (std::same_as<TypeParam, char>)
         {
-            for (size_t i = 0; i < seqan3::alphabet_size<TypeParam>/2; ++i)
+            for (size_t i = 0; i < seqan3::alphabet_size<TypeParam> / 2; ++i)
             {
                 seqan3::assign_rank_to(i, t0);
                 ASSERT_EQ(h(t0), i);
@@ -48,7 +47,7 @@ TYPED_TEST(alphabet_hashing, hash)
         std::hash<TypeParam const> h{};
         if constexpr (std::same_as<TypeParam, char>)
         {
-            for (size_t i = 0; i < seqan3::alphabet_size<TypeParam>/2; ++i)
+            for (size_t i = 0; i < seqan3::alphabet_size<TypeParam> / 2; ++i)
             {
                 TypeParam const t0 = seqan3::assign_rank_to(i, TypeParam{});
                 ASSERT_EQ(h(t0), i);
