@@ -1,19 +1,19 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
-#include <seqan3/std/algorithm>
-#include <seqan3/std/iterator>
-#include <seqan3/std/ranges>
+#include <gtest/gtest.h>
+
+#include <algorithm>
+#include <iterator>
+#include <ranges>
 #include <thread>
 #include <utility>
 #include <vector>
 
-#include <gtest/gtest.h>
-
 #include <seqan3/alphabet/nucleotide/dna4.hpp>
 #include <seqan3/test/performance/sequence_generator.hpp>
 #include <seqan3/utility/views/chunk.hpp>
@@ -47,8 +47,8 @@ struct execution_handler : public ::testing::Test
         for (unsigned i = 0; i < total_size; ++i)
         {
             EXPECT_EQ(buffer[i].first, i) << "Position: " << i;
-            EXPECT_EQ(buffer[i].second,
-                      sequence_collection1[i].size() + sequence_collection2[i].size()) << "Position: " << i;
+            EXPECT_EQ(buffer[i].second, sequence_collection1[i].size() + sequence_collection2[i].size())
+                << "Position: " << i;
         }
     }
 
@@ -58,15 +58,15 @@ struct execution_handler : public ::testing::Test
     // Do not use more than 4 threads if running in parallel
     execution_handler_t execution_helper()
     {
-        if constexpr(std::same_as<execution_handler_t, seqan3::detail::execution_handler_sequential>)
+        if constexpr (std::same_as<execution_handler_t, seqan3::detail::execution_handler_sequential>)
             return execution_handler_t{};
         else
             return execution_handler_t{std::min<uint32_t>(4, std::thread::hardware_concurrency())};
     }
 };
 
-auto simulate_alignment_with_range = [] (auto indexed_sequence_pairs,
-                                         std::function<void(std::pair<size_t, size_t>)> && callback)
+auto simulate_alignment_with_range =
+    [](auto indexed_sequence_pairs, std::function<void(std::pair<size_t, size_t>)> && callback)
 {
     for (auto && [sequence_pair, idx] : indexed_sequence_pairs)
         callback(std::pair{idx, std::get<0>(sequence_pair).size() + std::get<1>(sequence_pair).size()});
@@ -84,21 +84,22 @@ TYPED_TEST_P(execution_handler, execute_as_indexed_sequence_pairs)
     size_t pos = 0;
     size_t chunk_size = 4; // total_size is a multiple of chunk size.
 
-    auto indexed_sequence_pairs = seqan3::views::zip(seqan3::views::zip(this->sequence_collection1,
-                                                                        this->sequence_collection2),
-                                                     std::views::iota(0));
+    auto indexed_sequence_pairs =
+        seqan3::views::zip(seqan3::views::zip(this->sequence_collection1, this->sequence_collection2),
+                           std::views::iota(0));
     using range_iterator_t = std::ranges::iterator_t<decltype(indexed_sequence_pairs)>;
 
-    for (range_iterator_t it = indexed_sequence_pairs.begin();
-         it != indexed_sequence_pairs.end();
+    for (range_iterator_t it = indexed_sequence_pairs.begin(); it != indexed_sequence_pairs.end();
          it += chunk_size, pos += chunk_size)
     {
         std::ranges::subrange<range_iterator_t, range_iterator_t> chunk{it, std::next(it, chunk_size)};
-        exec_handler.execute(simulate_alignment_with_range, std::move(chunk), [pos, &buffer] (auto && res) mutable
-        {
-            *(buffer.begin() + pos) = std::forward<decltype(res)>(res);
-            ++pos;
-        });
+        exec_handler.execute(simulate_alignment_with_range,
+                             std::move(chunk),
+                             [pos, &buffer](auto && res) mutable
+                             {
+                                 *(buffer.begin() + pos) = std::forward<decltype(res)>(res);
+                                 ++pos;
+                             });
     }
 
     exec_handler.wait();
@@ -114,15 +115,17 @@ TYPED_TEST_P(execution_handler, bulk_execute)
     TypeParam exec_handler{this->execution_helper()};
 
     size_t chunk_size = 4;
-    auto indexed_sequence_pairs = seqan3::views::zip(seqan3::views::zip(this->sequence_collection1,
-                                                                        this->sequence_collection2),
-                                                     std::views::iota(0))
-                                | seqan3::views::chunk(chunk_size);
+    auto indexed_sequence_pairs =
+        seqan3::views::zip(seqan3::views::zip(this->sequence_collection1, this->sequence_collection2),
+                           std::views::iota(0))
+        | seqan3::views::chunk(chunk_size);
 
-    exec_handler.bulk_execute(simulate_alignment_with_range, indexed_sequence_pairs, [&] (auto && result_pair)
-    {
-        buffer[result_pair.first] = result_pair;
-    });
+    exec_handler.bulk_execute(simulate_alignment_with_range,
+                              indexed_sequence_pairs,
+                              [&](auto && result_pair)
+                              {
+                                  buffer[result_pair.first] = result_pair;
+                              });
     this->check_result(buffer);
 }
 
