@@ -1,14 +1,12 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
 #include <gtest/gtest.h>
 
-#include <seqan3/test/expect_range_eq.hpp>
-
 #include "sam_file_format_test_template.hpp"
 
 template <>
@@ -20,6 +18,11 @@ struct sam_file_read<seqan3::format_sam> : public sam_file_data
 
     using stream_type = std::istringstream;
 
+    std::string minimal_header{
+        R"(@HD	VN:1.6
+@SQ	SN:ref	LN:34
+)"};
+
     std::string big_header_input{
         R"(@HD	VN:1.6	SO:coordinate	SS:coordinate:queryname	GO:none
 @PG	ID:qc	PN:quality_control	CL:qc -f file1	DS:trim reads with low qual	VN:1.0.0
@@ -39,14 +42,15 @@ read2	42	ref	2	62	1H7M1D1M1S2H	ref	10	300	AGGCTGNAG	!##$&'()*	xy:B:S,3,4,5
 read3	43	ref	3	63	1S1M1P1M1I1M1I1D1M1S	ref	10	300	GGAGTATA	!!*+,-./
 )"};
 
-    std::string verbose_reads_input{"read1\t41\tref\t1\t61\t1S1M1D1M1I\t=\t10\t300\tACGT\t!##$\taa:A:c"
+    std::string verbose_reads_input{"@HD\tVN:1.6\n@SQ\tSN:ref\tLN:34\n"
+                                    "read1\t41\tref\t1\t61\t1S1M1D1M1I\t=\t10\t300\tACGT\t!##$\taa:A:c"
                                     "\tNM:i:-7"
                                     "\tAS:i:2"
                                     "\tff:f:3.1"
                                     "\tzz:Z:str"
                                     "\tCC:i:300"
                                     "\tcc:i:-300\n"
-                                    "read2\t42\tref\t2\t62\t1H7M1D1M1S\tref\t10\t300\tAGGCTGNAG\t!##$&'()*\tbc:B:c,-3"
+                                    "read2\t42\tref\t2\t62\t1H7M1D1M1S2H\tref\t10\t300\tAGGCTGNAG\t!##$&'()*\tbc:B:c,-3"
                                     "\tbC:B:C,3,200"
                                     "\tbs:B:s,-3,200,-300"
                                     "\tbS:B:S,300,40,500"
@@ -77,14 +81,6 @@ read3	43	ref	3	63	1S1M1P1M1I1M1I1D1M1S	ref	10	300	GGAGTATA	!!*+,-./
     // formatted output
     // -----------------------------------------------------------------------------------------------------------------
 
-    std::string simple_three_reads_output{// compared to simple_three_reads_input this has no hard clipping
-                                          R"(@HD	VN:1.6
-@SQ	SN:ref	LN:34
-read1	41	ref	1	61	1S1M1D1M1I	ref	10	300	ACGT	!##$	AS:i:2	NM:i:7
-read2	42	ref	2	62	7M1D1M1S	ref	10	300	AGGCTGNAG	!##$&'()*	xy:B:S,3,4,5
-read3	43	ref	3	63	1S1M1P1M1I1M1I1D1M1S	ref	10	300	GGAGTATA	!!*+,-./
-)"};
-
     std::string verbose_output{
         R"(@HD	VN:1.6	SO:unknown	GO:none
 @SQ	SN:ref	LN:34	AN:other_name
@@ -92,7 +88,7 @@ read3	43	ref	3	63	1S1M1P1M1I1M1I1D1M1S	ref	10	300	GGAGTATA	!!*+,-./
 @PG	ID:prog1	PN:cool_program	CL:./prog1	PP:a	DS:b	VN:c
 @CO	This is a comment.
 read1	41	ref	1	61	1S1M1D1M1I	ref	10	300	ACGT	!##$	AS:i:2	CC:i:300	NM:i:-7	aa:A:c	cc:i:-300	ff:f:3.1	zz:Z:str
-read2	42	ref	2	62	7M1D1M1S	ref	10	300	AGGCTGNAG	!##$&'()*	bC:B:C,3,200	bI:B:I,294967296	bS:B:S,300,40,500	bc:B:c,-3	bf:B:f,3.5,0.1,43.8	bi:B:i,-3,200,-66000	bs:B:s,-3,200,-300
+read2	42	ref	2	62	1H7M1D1M1S2H	ref	10	300	AGGCTGNAG	!##$&'()*	bC:B:C,3,200	bI:B:I,294967296	bS:B:S,300,40,500	bc:B:c,-3	bf:B:f,3.5,0.1,43.8	bi:B:i,-3,200,-66000	bs:B:s,-3,200,-300
 read3	43	ref	3	63	1S1M1P1M1I1M1I1D1M1S	ref	10	300	GGAGTATA	!!*+,-./
 )"};
 
@@ -323,7 +319,7 @@ TEST_F(sam_format, format_error_invalid_cigar)
     std::istringstream istream(std::string("*\t0\t*\t0\t0\t5Z\t*\t0\t0\t*\t*\n"));
     {
         seqan3::sam_file_input fin{istream, seqan3::format_sam{}};
-        EXPECT_THROW(fin.begin(), seqan3::format_error);
+        EXPECT_THROW(fin.begin(), seqan3::invalid_char_assignment);
     }
     // negative number as operation count
     {
@@ -355,32 +351,6 @@ TEST_F(sam_format, format_error_invalid_sam_tag_format)
     }
 }
 
-TEST_F(sam_format, short_cigar_string_with_softclipping)
-{
-    using seqan3::operator""_dna5;
-
-    // The member function transfer_soft_clipping_to needs to work on 2 element cigar strings
-    {
-        std::istringstream istream("id	16	ref	0	255	10M5S	*	0	0	AGAGGGGGATAACCA	*\n");
-        seqan3::sam_file_input fin{istream,
-                                   ref_ids,
-                                   ref_sequences,
-                                   seqan3::format_sam{},
-                                   seqan3::fields<seqan3::field::alignment>{}};
-        EXPECT_RANGE_EQ(std::get<1>(std::get<0>(*fin.begin())), "AGAGGGGGAT"_dna5);
-    }
-
-    {
-        std::istringstream istream("id	16	ref	0	255	5S10M	*	0	0	AGAGGGGGATAACCA	*\n");
-        seqan3::sam_file_input fin{istream,
-                                   ref_ids,
-                                   ref_sequences,
-                                   seqan3::format_sam{},
-                                   seqan3::fields<seqan3::field::alignment>{}};
-        EXPECT_RANGE_EQ(std::get<1>(std::get<0>(*fin.begin())), "GGGATAACCA"_dna5);
-    }
-}
-
 TEST_F(sam_format, write_different_header)
 {
     std::ostringstream ostream;
