@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -16,7 +16,7 @@
 #include <seqan3/alphabet/quality/phred42.hpp>
 #include <seqan3/io/sam_file/input.hpp>
 #include <seqan3/test/expect_range_eq.hpp>
-#include <seqan3/test/tmp_filename.hpp>
+#include <seqan3/test/tmp_directory.hpp>
 #include <seqan3/utility/views/convert.hpp>
 
 using seqan3::operator""_dna4;
@@ -71,22 +71,24 @@ TEST_F(sam_file_input_f, construct_by_filename)
 {
     /* just the filename */
     {
-        seqan3::test::tmp_filename filename{"sam_file_input_constructor.sam"};
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "sam_file_input_constructor.sam";
 
         {
-            std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+            std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
         }
 
-        EXPECT_NO_THROW(seqan3::sam_file_input<>{filename.get_path()});
+        EXPECT_NO_THROW(seqan3::sam_file_input<>{filename});
     }
 
     // correct format check is done by tests of that format
 
     /* wrong extension */
     {
-        seqan3::test::tmp_filename filename{"sam_file_input_constructor.xyz"};
-        std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
-        EXPECT_THROW(seqan3::sam_file_input<>{filename.get_path()}, seqan3::unhandled_extension_error);
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "sam_file_input_constructor.xyz";
+        std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
+        EXPECT_THROW(seqan3::sam_file_input<>{filename}, seqan3::unhandled_extension_error);
     }
 
     /* non-existent file*/
@@ -103,18 +105,18 @@ TEST_F(sam_file_input_f, construct_by_filename)
 
     /* filename + fields */
     {
-        seqan3::test::tmp_filename filename{"sam_file_input_constructor.sam"};
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "sam_file_input_constructor.sam";
 
         {
-            std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+            std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
         }
 
         using fields_seq = seqan3::fields<seqan3::field::seq>;
 
-        EXPECT_NO_THROW(
-            (seqan3::sam_file_input<seqan3::sam_file_input_default_traits<>,
-                                    fields_seq,
-                                    seqan3::type_list<seqan3::format_sam>>{filename.get_path(), fields_seq{}}));
+        EXPECT_NO_THROW((seqan3::sam_file_input<seqan3::sam_file_input_default_traits<>,
+                                                fields_seq,
+                                                seqan3::type_list<seqan3::format_sam>>{filename, fields_seq{}}));
     }
 }
 
@@ -139,10 +141,8 @@ TEST_F(sam_file_input_f, default_template_args_and_deduction_guides)
     using comp0 = seqan3::sam_file_input_default_traits<>;
     using comp1 = seqan3::fields<seqan3::field::seq,
                                  seqan3::field::id,
-                                 seqan3::field::offset,
                                  seqan3::field::ref_id,
                                  seqan3::field::ref_offset,
-                                 seqan3::field::alignment,
                                  seqan3::field::cigar,
                                  seqan3::field::mapq,
                                  seqan3::field::qual,
@@ -164,13 +164,14 @@ TEST_F(sam_file_input_f, default_template_args_and_deduction_guides)
 
     /* guided filename constructor */
     {
-        seqan3::test::tmp_filename filename{"sam_file_input_constructor.sam"};
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "sam_file_input_constructor.sam";
 
         {
-            std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+            std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
         }
 
-        seqan3::sam_file_input fin{filename.get_path()};
+        seqan3::sam_file_input fin{filename};
 
         using t = decltype(fin);
         EXPECT_TRUE((std::is_same_v<typename t::traits_type, comp0>));
@@ -181,13 +182,14 @@ TEST_F(sam_file_input_f, default_template_args_and_deduction_guides)
 
     /* guided filename constructor + custom fields */
     {
-        seqan3::test::tmp_filename filename{"sam_file_input_constructor.sam"};
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "sam_file_input_constructor.sam";
 
         {
-            std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+            std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
         }
 
-        seqan3::sam_file_input fin{filename.get_path(), seqan3::fields<seqan3::field::seq>{}};
+        seqan3::sam_file_input fin{filename, seqan3::fields<seqan3::field::seq>{}};
 
         using t = decltype(fin);
         EXPECT_TRUE((std::is_same_v<typename t::traits_type, comp0>));
@@ -222,10 +224,12 @@ TEST_F(sam_file_input_f, default_template_args_and_deduction_guides)
 
 TEST_F(sam_file_input_f, empty_file)
 {
-    seqan3::test::tmp_filename filename{"empty.sam"};
-    std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+    seqan3::test::tmp_directory tmp{};
+    auto filename = tmp.path() / "empty.sam";
 
-    seqan3::sam_file_input fin{filename.get_path()};
+    std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
+
+    seqan3::sam_file_input fin{filename};
 
     EXPECT_EQ(fin.begin(), fin.end());
 }
@@ -249,7 +253,7 @@ TEST_F(sam_file_input_f, record_reading)
         EXPECT_RANGE_EQ(rec.id(), id_comp[counter]);
         EXPECT_RANGE_EQ(rec.base_qualities(), qual_comp[counter]);
 
-        counter++;
+        ++counter;
     }
 
     EXPECT_EQ(counter, 3u);
@@ -268,7 +272,7 @@ TEST_F(sam_file_input_f, record_reading_custom_fields)
         EXPECT_RANGE_EQ(seq, seq_comp[counter]);
         EXPECT_RANGE_EQ(id, id_comp[counter]);
 
-        counter++;
+        ++counter;
     }
 
     EXPECT_EQ(counter, 3u);
@@ -291,7 +295,7 @@ TEST_F(sam_file_input_f, file_view)
         EXPECT_RANGE_EQ(rec.id(), id_comp[counter]);
         EXPECT_RANGE_EQ(rec.base_qualities(), qual_comp[counter]);
 
-        counter++;
+        ++counter;
     }
 
     EXPECT_EQ(counter, 3u);
@@ -311,7 +315,7 @@ void decompression_impl(fixture_t & fix, input_file_t & fin)
         EXPECT_RANGE_EQ(rec.id(), fix.id_comp[counter]);
         EXPECT_RANGE_EQ(rec.base_qualities(), fix.qual_comp[counter]);
 
-        counter++;
+        ++counter;
     }
 
     EXPECT_EQ(counter, 3u);
@@ -335,15 +339,16 @@ std::string input_gz{
 
 TEST_F(sam_file_input_f, decompression_by_filename_gz)
 {
-    seqan3::test::tmp_filename filename{"sam_file_output_test.sam.gz"};
+    seqan3::test::tmp_directory tmp{};
+    auto filename = tmp.path() / "sam_file_output_test.sam.gz";
 
     {
-        std::ofstream of{filename.get_path(), std::ios::binary};
+        std::ofstream of{filename, std::ios::binary};
 
         std::copy(input_gz.begin(), input_gz.end(), std::ostreambuf_iterator<char>{of});
     }
 
-    seqan3::sam_file_input fin{filename.get_path()};
+    seqan3::sam_file_input fin{filename};
 
     decompression_impl(*this, fin);
 }
@@ -389,15 +394,16 @@ std::string input_bgzf{
 
 TEST_F(sam_file_input_f, decompression_by_filename_bgzf)
 {
-    seqan3::test::tmp_filename filename{"sam_file_output_test.sam.bgzf"};
+    seqan3::test::tmp_directory tmp{};
+    auto filename = tmp.path() / "sam_file_output_test.sam.bgzf";
 
     {
-        std::ofstream of{filename.get_path(), std::ios::binary};
+        std::ofstream of{filename, std::ios::binary};
 
         std::copy(input_bgzf.begin(), input_bgzf.end(), std::ostreambuf_iterator<char>{of});
     }
 
-    seqan3::sam_file_input fin{filename.get_path()};
+    seqan3::sam_file_input fin{filename};
 
     decompression_impl(*this, fin);
 }
@@ -439,15 +445,16 @@ std::string input_bz2{
 
 TEST_F(sam_file_input_f, decompression_by_filename_bz2)
 {
-    seqan3::test::tmp_filename filename{"sam_file_output_test.sam.bz2"};
+    seqan3::test::tmp_directory tmp{};
+    auto filename = tmp.path() / "sam_file_output_test.sam.bz2";
 
     {
-        std::ofstream of{filename.get_path(), std::ios::binary};
+        std::ofstream of{filename, std::ios::binary};
 
         std::copy(input_bz2.begin(), input_bz2.end(), std::ostreambuf_iterator<char>{of});
     }
 
-    seqan3::sam_file_input fin{filename.get_path()};
+    seqan3::sam_file_input fin{filename};
 
     decompression_impl(*this, fin);
 }
@@ -482,121 +489,14 @@ TEST_F(sam_file_input_f, read_empty_bz2_file)
 #endif
 
 // ----------------------------------------------------------------------------
-// SAM format specificities
+// BAM format specificities
 // ----------------------------------------------------------------------------
 
-struct sam_file_input_sam_format_f : public sam_file_input_f
+struct sam_file_input_bam_format_f : public sam_file_input_f
 {
     std::vector<seqan3::dna4_vector> const ref_seqs = {"ACTGATCGAGAGGATCTAGAGGAGATCGTAGGAC"_dna4};
     std::vector<std::string> const ref_ids = {"ref"};
 
-    std::vector<seqan3::gapped<seqan3::dna4>> ref_seq_gapped1 = {'A'_dna4, 'C'_dna4, 'T'_dna4, 'G'_dna4};
-    std::vector<seqan3::gapped<seqan3::dna4>> ref_seq_gapped2 =
-        {'C'_dna4, 'T'_dna4, 'G'_dna4, 'A'_dna4, 'T'_dna4, 'C'_dna4, 'G'_dna4, 'A'_dna4, 'G'_dna4};
-    std::vector<seqan3::gapped<seqan3::dna4>> ref_seq_gapped3 = {
-        'T'_dna4,
-        'G'_dna4,
-        'A'_dna4,
-        'T'_dna4,
-        'C'_dna4,
-        'G'_dna4,
-        'A'_dna4,
-        'G'_dna4,
-    };
-
-    std::vector<std::pair<std::vector<seqan3::gapped<seqan3::dna4>>, std::vector<seqan3::gapped<seqan3::dna5>>>>
-        alignments_expected{
-            {ref_seq_gapped1, std::vector<seqan3::gapped<seqan3::dna5>>{'C'_dna5, seqan3::gap{}, 'G'_dna5, 'T'_dna5}},
-            {ref_seq_gapped2,
-             std::vector<seqan3::gapped<seqan3::dna5>>{'A'_dna5,
-                                                       'G'_dna5,
-                                                       'G'_dna5,
-                                                       'C'_dna5,
-                                                       'T'_dna5,
-                                                       'G'_dna5,
-                                                       'N'_dna5,
-                                                       seqan3::gap{},
-                                                       'A'_dna5}},
-            {ref_seq_gapped3,
-             std::vector<seqan3::gapped<seqan3::dna5>>{'G'_dna5,
-                                                       seqan3::gap{},
-                                                       'A'_dna5,
-                                                       'G'_dna5,
-                                                       'T'_dna5,
-                                                       'A'_dna5,
-                                                       seqan3::gap{},
-                                                       'T'_dna5}}};
-};
-
-TEST_F(sam_file_input_sam_format_f, construct_by_filename_and_read_alignments)
-{
-    seqan3::test::tmp_filename filename{"sam_file_input_constructor.sam"};
-    {
-        std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
-        filecreator << input;
-    }
-
-    seqan3::sam_file_input fin{filename.get_path(), ref_ids, ref_seqs, seqan3::fields<seqan3::field::alignment>{}};
-
-    EXPECT_EQ(fin.header().ref_ids(), ref_ids);
-
-    size_t counter = 0;
-    for (auto & [alignment] : fin)
-    {
-        EXPECT_RANGE_EQ(std::get<0>(alignment), std::get<0>(alignments_expected[counter]));
-        EXPECT_RANGE_EQ(std::get<0>(alignment), std::get<0>(alignments_expected[counter]));
-
-        counter++;
-    }
-
-    EXPECT_EQ(counter, 3u);
-}
-
-TEST_F(sam_file_input_sam_format_f, construct_from_stream_and_read_alignments)
-{
-    seqan3::sam_file_input fin{std::istringstream{input},
-                               ref_ids,
-                               ref_seqs,
-                               seqan3::format_sam{},
-                               seqan3::fields<seqan3::field::alignment>{}};
-
-    EXPECT_EQ(fin.header().ref_ids(), ref_ids);
-
-    size_t counter = 0;
-    for (auto & [alignment] : fin)
-    {
-        EXPECT_RANGE_EQ(std::get<0>(alignment), std::get<0>(alignments_expected[counter]));
-        EXPECT_RANGE_EQ(std::get<0>(alignment), std::get<0>(alignments_expected[counter]));
-
-        counter++;
-    }
-
-    EXPECT_EQ(counter, 3u);
-}
-
-TEST_F(sam_file_input_sam_format_f, construct_from_stream_and_read_alignment_with_dummy)
-{
-    seqan3::sam_file_input fin{std::istringstream{input},
-                               seqan3::format_sam{},
-                               seqan3::fields<seqan3::field::alignment>{}};
-
-    size_t counter = 0;
-    for (auto & [alignment] : fin)
-    {
-        EXPECT_EQ(std::get<1>(alignment), std::get<1>(alignments_expected[counter]));
-
-        counter++;
-    }
-
-    EXPECT_EQ(counter, 3u);
-}
-
-// ----------------------------------------------------------------------------
-// BAM format specificities
-// ----------------------------------------------------------------------------
-
-struct sam_file_input_bam_format_f : public sam_file_input_sam_format_f
-{
     std::string binary_input{
         // corresponds to 'input' from sam_file_input_f fixture
         '\x1F', '\x8B', '\x08', '\x04', '\x00', '\x00', '\x00', '\x00', '\x00', '\xFF', '\x06', '\x00', '\x42', '\x43',
@@ -628,32 +528,29 @@ struct sam_file_input_bam_format_f : public sam_file_input_sam_format_f
 #if defined(SEQAN3_HAS_ZLIB)
 TEST_F(sam_file_input_bam_format_f, construct_by_filename)
 {
-    seqan3::test::tmp_filename filename{"sam_file_input_constructor.bam"};
+    seqan3::test::tmp_directory tmp{};
+    auto filename = tmp.path() / "sam_file_input_constructor.bam";
     {
-        std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+        std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
         filecreator << binary_input;
     }
 
-    seqan3::sam_file_input fin{
-        filename.get_path(),
-        ref_ids,
-        ref_seqs,
-        seqan3::fields<seqan3::field::id, seqan3::field::seq, seqan3::field::qual, seqan3::field::alignment>{}};
+    seqan3::sam_file_input fin{filename,
+                               ref_ids,
+                               ref_seqs,
+                               seqan3::fields<seqan3::field::id, seqan3::field::seq, seqan3::field::qual>{}};
 
     EXPECT_EQ(fin.header().ref_ids(), ref_ids);
     EXPECT_EQ(fin.header().comments[0], std::string{"This is a comment."});
 
     size_t counter = 0;
-    for (auto & [id, seq, qual, alignment] : fin)
+    for (auto & [id, seq, qual] : fin)
     {
         EXPECT_EQ(id, id_comp[counter]);
         EXPECT_EQ(seq, seq_comp[counter]);
         EXPECT_EQ(qual, qual_comp[counter]);
 
-        EXPECT_RANGE_EQ(std::get<0>(alignment), std::get<0>(alignments_expected[counter]));
-        EXPECT_RANGE_EQ(std::get<0>(alignment), std::get<0>(alignments_expected[counter]));
-
-        counter++;
+        ++counter;
     }
 
     EXPECT_EQ(counter, 3u);
@@ -663,27 +560,23 @@ TEST_F(sam_file_input_bam_format_f, construct_by_stream)
 {
     std::istringstream stream{binary_input};
 
-    seqan3::sam_file_input fin{
-        stream,
-        ref_ids,
-        ref_seqs,
-        seqan3::format_bam{},
-        seqan3::fields<seqan3::field::id, seqan3::field::seq, seqan3::field::qual, seqan3::field::alignment>{}};
+    seqan3::sam_file_input fin{stream,
+                               ref_ids,
+                               ref_seqs,
+                               seqan3::format_bam{},
+                               seqan3::fields<seqan3::field::id, seqan3::field::seq, seqan3::field::qual>{}};
 
     EXPECT_EQ(fin.header().ref_ids(), ref_ids);
     EXPECT_EQ(fin.header().comments[0], std::string{"This is a comment."});
 
     size_t counter = 0;
-    for (auto & [id, seq, qual, alignment] : fin)
+    for (auto & [id, seq, qual] : fin)
     {
         EXPECT_EQ(id, id_comp[counter]);
         EXPECT_EQ(seq, seq_comp[counter]);
         EXPECT_EQ(qual, qual_comp[counter]);
 
-        EXPECT_RANGE_EQ(std::get<0>(alignment), std::get<0>(alignments_expected[counter]));
-        EXPECT_RANGE_EQ(std::get<0>(alignment), std::get<0>(alignments_expected[counter]));
-
-        counter++;
+        ++counter;
     }
 
     EXPECT_EQ(counter, 3u);
