@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -8,11 +8,13 @@
 #include <gtest/gtest.h>
 
 #include <iterator>
+#include <ranges>
 #include <sstream>
+#include <type_traits>
 
 #include <seqan3/io/sam_file/input.hpp>
 #include <seqan3/io/sam_file/output.hpp>
-#include <seqan3/test/tmp_filename.hpp>
+#include <seqan3/test/tmp_directory.hpp>
 
 using seqan3::operator""_dna4;
 using seqan3::operator""_dna5;
@@ -54,29 +56,33 @@ TEST(general, construct_by_filename)
 {
     /* just the filename */
     {
-        seqan3::test::tmp_filename filename{"sam_file_output_constructor.sam"};
-        EXPECT_NO_THROW(seqan3::sam_file_output<>{filename.get_path()});
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "sam_file_output_constructor.sam";
+        EXPECT_NO_THROW(seqan3::sam_file_output<>{filename});
     }
 
     /* wrong extension */
     {
-        seqan3::test::tmp_filename filename{"sam_file_output_constructor.xyz"};
-        std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
-        EXPECT_THROW(seqan3::sam_file_output<>{filename.get_path()}, seqan3::unhandled_extension_error);
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "sam_file_output_constructor.xyz";
+        std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
+        EXPECT_THROW(seqan3::sam_file_output<>{filename}, seqan3::unhandled_extension_error);
     }
 
     /* unknown file */
     {
-        seqan3::test::tmp_filename filename{"I/do/not/exist.sam"};
-        EXPECT_THROW(seqan3::sam_file_output<>{filename.get_path()}, seqan3::file_open_error);
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "I/do/not/exist.sam";
+        EXPECT_THROW(seqan3::sam_file_output<>{filename}, seqan3::file_open_error);
     }
 
     /* filename + fields */
     using fields_seq = seqan3::fields<seqan3::field::seq>;
     {
-        seqan3::test::tmp_filename filename{"sam_file_output_constructor.sam"};
-        EXPECT_NO_THROW((seqan3::sam_file_output<fields_seq, seqan3::type_list<seqan3::format_sam>>{filename.get_path(),
-                                                                                                    fields_seq{}}));
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "sam_file_output_constructor.sam";
+        EXPECT_NO_THROW(
+            (seqan3::sam_file_output<fields_seq, seqan3::type_list<seqan3::format_sam>>{filename, fields_seq{}}));
     }
 }
 
@@ -98,10 +104,8 @@ TEST(general, default_template_args_and_deduction_guides)
 {
     using comp1 = seqan3::fields<seqan3::field::seq,
                                  seqan3::field::id,
-                                 seqan3::field::offset,
                                  seqan3::field::ref_id,
                                  seqan3::field::ref_offset,
-                                 seqan3::field::alignment,
                                  seqan3::field::cigar,
                                  seqan3::field::mapq,
                                  seqan3::field::qual,
@@ -122,9 +126,10 @@ TEST(general, default_template_args_and_deduction_guides)
 
     /* guided filename constructor */
     {
-        seqan3::test::tmp_filename filename{"sam_file_output_constructor.sam"};
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "sam_file_output_constructor.sam";
 
-        seqan3::sam_file_output fout{filename.get_path()};
+        seqan3::sam_file_output fout{filename};
 
         using t = decltype(fout);
         EXPECT_TRUE((std::is_same_v<typename t::selected_field_ids, comp1>));
@@ -134,13 +139,13 @@ TEST(general, default_template_args_and_deduction_guides)
 
     /* guided filename constructor + custom fields */
     {
-        seqan3::test::tmp_filename filename{"sam_file_output_constructor.sam"};
+        seqan3::test::tmp_directory tmp{};
+        auto filename = tmp.path() / "sam_file_output_constructor.sam";
 
-        seqan3::sam_file_output fout{filename.get_path(), seqan3::fields<seqan3::field::alignment>{}};
+        seqan3::sam_file_output fout{filename, seqan3::fields<seqan3::field::cigar>{}};
 
         using t = decltype(fout);
-        EXPECT_TRUE(
-            (std::is_same_v<typename t::selected_field_ids, seqan3::fields<seqan3::field::alignment>>)); // changed
+        EXPECT_TRUE((std::is_same_v<typename t::selected_field_ids, seqan3::fields<seqan3::field::cigar>>)); // changed
         EXPECT_TRUE((std::is_same_v<typename t::valid_formats, comp2>));
         EXPECT_TRUE((std::is_same_v<typename t::stream_char_type, comp3>));
     }
@@ -194,6 +199,41 @@ void assign_impl(source_t && source)
     EXPECT_EQ(reinterpret_cast<std::ostringstream &>(fout.get_stream()).str(), output_comp);
 }
 
+// ----------------------------------------------------------------------------
+// header
+// ----------------------------------------------------------------------------
+// See https://github.com/seqan/seqan3/issues/3137
+TEST(header, copy_program_info_t)
+{
+    std::string comp =
+        R"(@HD	VN:1.6	SO:unknown	GO:none
+@SQ	SN:ref	LN:26
+@PG	ID:prog1	PN:cool_program
+@CO	This is a comment.
+read1	41	ref	1	61	1S1M1D1M1I	ref	10	300	ACGT	!##$	AS:i:2	NM:i:7
+)";
+    seqan3::sam_file_input fin{std::istringstream{comp}, seqan3::format_sam{}};
+    auto & input_header(fin.header());
+
+    // We would like to test that (some of) the headers can be copied even if ref_ids_types do not match.
+    // input_ref_ids_type is std::deque<std::string> by default.
+    using input_ref_ids_type = std::remove_cvref_t<decltype(input_header.ref_ids())>;
+    using output_ref_ids_type = std::array<std::string, 0>;
+    static_assert(!std::is_same_v<input_ref_ids_type, output_ref_ids_type>);
+
+    seqan3::sam_file_output fout{std::ostringstream{},
+                                 output_ref_ids_type{},
+                                 std::ranges::empty_view<std::size_t>{},
+                                 seqan3::format_sam{}};
+    auto & output_header(fout.header());
+    output_header.program_infos = input_header.program_infos;
+
+    // Verify that the above was sufficient to copy the headers.
+    auto const & pg_infos(output_header.program_infos);
+    EXPECT_FALSE(pg_infos.empty());
+    EXPECT_EQ("cool_program", pg_infos.front().name);
+}
+
 // ----------------------------------------------------------------------------
 // row
 // ----------------------------------------------------------------------------
@@ -367,6 +407,29 @@ TEST(row, print_header_in_file)
     EXPECT_EQ(reinterpret_cast<std::ostringstream &>(fout.get_stream()).str(), expected_out);
 }
 
+// https://github.com/seqan/seqan3/issues/3124
+TEST(row, issue3124)
+{
+    seqan3::sam_file_output fout{std::ostringstream{},
+                                 std::vector<std::string>{"ref1", "ref2"},
+                                 std::vector<int32_t>{234511, 243243},
+                                 seqan3::format_sam{},
+                                 seqan3::fields<seqan3::field::id>{}};
+
+    fout.emplace_back(std::string("read1"));
+
+    fout.get_stream().flush();
+
+    std::string const expected_out{
+        "@HD\tVN:1.6\n"
+        "@SQ\tSN:ref1\tLN:234511\n"
+        "@SQ\tSN:ref2\tLN:243243\n"
+        "read1\t0\t*\t0\t0\t*\t*\t0\t0\t*\t*\n" // empty read
+    };
+
+    EXPECT_EQ(reinterpret_cast<std::ostringstream &>(fout.get_stream()).str(), expected_out);
+}
+
 TEST(row, print_header_in_record)
 {
     std::vector<std::string> const ref_ids{"ref1", "ref2"};
@@ -528,7 +591,8 @@ read3	43	ref	3	63	1S1M1D1M1I1M1I1D1M1S	ref	10	300	GGAGTATA	!!*+,-./
 #if defined(SEQAN3_HAS_ZLIB)
 TEST(rows, write_bam_file)
 {
-    seqan3::test::tmp_filename const filename{"in_out.bam"};
+    seqan3::test::tmp_directory tmp{};
+    auto filename = tmp.path() / "in_out.bam";
 
     std::vector<std::string> const ref_ids{"ref"};
     std::vector<seqan3::dna4_vector> const ref_seqs{"ACTAGCTAGGAGGACTAGCATCGATC"_dna4};
@@ -544,12 +608,12 @@ read3	43	ref	3	63	1S1M1D1M1I1M1I1D1M1S	ref	10	300	GGAGTATA	!!*+,-./
 )";
     {
         seqan3::sam_file_input fin{std::istringstream{comp}, ref_ids, ref_seqs, seqan3::format_sam{}};
-        seqan3::sam_file_output fout{filename.get_path()};
+        seqan3::sam_file_output fout{filename};
 
         fin | fout;
     }
 
-    seqan3::sam_file_input fin2{filename.get_path(), ref_ids, ref_seqs};
+    seqan3::sam_file_input fin2{filename, ref_ids, ref_seqs};
     seqan3::sam_file_output fout2{std::ostringstream{}, seqan3::format_sam{}};
 
     fin2 | fout2;
@@ -569,14 +633,14 @@ TEST(rows, convert_sam_to_blast)
 // compression
 // ----------------------------------------------------------------------------
 
-std::string compression_by_filename_impl(seqan3::test::tmp_filename & filename)
+std::string compression_by_filename_impl(std::filesystem::path const & filename)
 {
     {
         // explicitly only test compression on sam format
         seqan3::sam_file_output<typename seqan3::sam_file_output<>::selected_field_ids,
                                 seqan3::type_list<seqan3::format_sam>,
                                 seqan3::ref_info_not_given>
-            fout{filename.get_path()};
+            fout{filename};
 
         for (size_t i = 0; i < 3; ++i)
         {
@@ -591,7 +655,7 @@ std::string compression_by_filename_impl(seqan3::test::tmp_filename & filename)
     std::string buffer{};
 
     {
-        std::ifstream fi{filename.get_path(), std::ios::binary};
+        std::ifstream fi{filename, std::ios::binary};
 
         buffer = std::string{std::istreambuf_iterator<char>{fi}, std::istreambuf_iterator<char>{}};
     }
@@ -635,7 +699,9 @@ std::string expected_bgzf{
 
 TEST(compression, by_filename_gz)
 {
-    seqan3::test::tmp_filename filename{"sam_file_output_test.sam.gz"};
+
+    seqan3::test::tmp_directory tmp{};
+    auto filename = tmp.path() / "sam_file_output_test.sam.gz";
 
     std::string buffer = compression_by_filename_impl(filename);
     buffer[9] = '\x00'; // zero out OS byte.
@@ -657,7 +723,8 @@ TEST(compression, by_stream_gz)
 
 TEST(compression, by_filename_bgzf)
 {
-    seqan3::test::tmp_filename filename{"sam_file_output_test.sam.bgzf"};
+    seqan3::test::tmp_directory tmp{};
+    auto filename = tmp.path() / "sam_file_output_test.sam.bgzf";
 
     std::string buffer = compression_by_filename_impl(filename);
     buffer[9] = '\x00'; // zero out OS byte.
@@ -690,7 +757,8 @@ std::string expected_bz2{'\x42', '\x5A', '\x68', '\x39', '\x31', '\x41', '\x59',
 
 TEST(compression, by_filename_bz2)
 {
-    seqan3::test::tmp_filename filename{"sam_file_output_test.sam.bz2"};
+    seqan3::test::tmp_directory tmp{};
+    auto filename = tmp.path() / "sam_file_output_test.sam.bz2";
 
     std::string buffer = compression_by_filename_impl(filename);
     EXPECT_EQ(buffer, expected_bz2);
