@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -15,7 +15,7 @@
 #include <seqan3/alphabet/detail/debug_stream_alphabet.hpp>
 #include <seqan3/io/sequence_file/input.hpp>
 #include <seqan3/test/expect_range_eq.hpp>
-#include <seqan3/test/tmp_filename.hpp>
+#include <seqan3/test/tmp_directory.hpp>
 #include <seqan3/utility/views/convert.hpp>
 
 using seqan3::operator""_dna5;
@@ -59,22 +59,25 @@ TEST_F(sequence_file_input_f, construct_by_filename)
 {
     /* just the filename */
     {
-        seqan3::test::tmp_filename filename{"sequence_file_input_constructor.fasta"};
+        seqan3::test::tmp_directory tmp;
+        auto filename = tmp.path() / "sequence_file_input_constructor.fasta";
 
         {
-            std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+            std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
         }
 
-        EXPECT_NO_THROW(seqan3::sequence_file_input<>{filename.get_path()});
+        EXPECT_NO_THROW(seqan3::sequence_file_input<>{filename});
     }
 
     // correct format check is done by tests of that format
 
     /* wrong extension */
     {
-        seqan3::test::tmp_filename filename{"sequence_file_input_constructor.xyz"};
-        std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
-        EXPECT_THROW(seqan3::sequence_file_input<>{filename.get_path()}, seqan3::unhandled_extension_error);
+        seqan3::test::tmp_directory tmp;
+        auto filename = tmp.path() / "sequence_file_input_constructor.xyz";
+
+        std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
+        EXPECT_THROW(seqan3::sequence_file_input<>{filename}, seqan3::unhandled_extension_error);
     }
 
     /* non-existent file */
@@ -86,16 +89,16 @@ TEST_F(sequence_file_input_f, construct_by_filename)
     {
         using fields_seq = seqan3::fields<seqan3::field::seq>;
 
-        seqan3::test::tmp_filename filename{"sequence_file_input_constructor.fasta"};
+        seqan3::test::tmp_directory tmp;
+        auto filename = tmp.path() / "sequence_file_input_constructor.fasta";
 
         {
-            std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+            std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
         }
 
-        EXPECT_NO_THROW(
-            (seqan3::sequence_file_input<seqan3::sequence_file_input_default_traits_dna,
-                                         fields_seq,
-                                         seqan3::type_list<seqan3::format_fasta>>{filename.get_path(), fields_seq{}}));
+        EXPECT_NO_THROW((seqan3::sequence_file_input<seqan3::sequence_file_input_default_traits_dna,
+                                                     fields_seq,
+                                                     seqan3::type_list<seqan3::format_fasta>>{filename, fields_seq{}}));
     }
 }
 
@@ -136,13 +139,14 @@ TEST_F(sequence_file_input_f, default_template_args_and_deduction_guides)
 
     /* guided filename constructor */
     {
-        seqan3::test::tmp_filename filename{"sequence_file_input_constructor.fasta"};
+        seqan3::test::tmp_directory tmp;
+        auto filename = tmp.path() / "sequence_file_input_constructor.fasta";
 
         {
-            std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+            std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
         }
 
-        seqan3::sequence_file_input fin{filename.get_path()};
+        seqan3::sequence_file_input fin{filename};
 
         using t = decltype(fin);
         EXPECT_TRUE((std::is_same_v<typename t::traits_type, comp0>));
@@ -153,13 +157,14 @@ TEST_F(sequence_file_input_f, default_template_args_and_deduction_guides)
 
     /* guided filename constructor + custom fields */
     {
-        seqan3::test::tmp_filename filename{"sequence_file_input_constructor.fasta"};
+        seqan3::test::tmp_directory tmp;
+        auto filename = tmp.path() / "sequence_file_input_constructor.fasta";
 
         {
-            std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+            std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
         }
 
-        seqan3::sequence_file_input fin{filename.get_path(), seqan3::fields<seqan3::field::seq>{}};
+        seqan3::sequence_file_input fin{filename, seqan3::fields<seqan3::field::seq>{}};
 
         using t = decltype(fin);
         EXPECT_TRUE((std::is_same_v<typename t::traits_type, comp0>));
@@ -194,10 +199,12 @@ TEST_F(sequence_file_input_f, default_template_args_and_deduction_guides)
 
 TEST_F(sequence_file_input_f, empty_file)
 {
-    seqan3::test::tmp_filename filename{"empty.fasta"};
-    std::ofstream filecreator{filename.get_path(), std::ios::out | std::ios::binary};
+    seqan3::test::tmp_directory tmp;
+    auto filename = tmp.path() / "empty.fasta";
 
-    seqan3::sequence_file_input fin{filename.get_path()};
+    std::ofstream filecreator{filename, std::ios::out | std::ios::binary};
+
+    seqan3::sequence_file_input fin{filename};
 
     EXPECT_EQ(fin.begin(), fin.end());
 }
@@ -221,7 +228,7 @@ TEST_F(sequence_file_input_f, record_reading)
         EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
         EXPECT_TRUE(empty(rec.base_qualities()));
 
-        counter++;
+        ++counter;
     }
 
     EXPECT_EQ(counter, 3u);
@@ -239,7 +246,7 @@ TEST_F(sequence_file_input_f, record_reading_struct_bind)
         EXPECT_RANGE_EQ(id, id_comp[counter]);
         EXPECT_TRUE(empty(qual));
 
-        counter++;
+        ++counter;
     }
 
     EXPECT_EQ(counter, 3u);
@@ -283,7 +290,7 @@ TEST_F(sequence_file_input_f, file_view)
         EXPECT_RANGE_EQ(rec.sequence(), seq_comp[counter]);
         EXPECT_TRUE(empty(rec.base_qualities()));
 
-        counter++;
+        ++counter;
     }
 
     EXPECT_EQ(counter, 3u);
@@ -303,7 +310,7 @@ void decompression_impl(fixture_t & fix, input_file_t & fin)
         EXPECT_RANGE_EQ(rec.id(), fix.id_comp[counter]);
         EXPECT_TRUE(empty(rec.base_qualities()));
 
-        counter++;
+        ++counter;
     }
 
     EXPECT_EQ(counter, 3u);
@@ -320,15 +327,16 @@ std::string input_gz{
 
 TEST_F(sequence_file_input_f, decompression_by_filename_gz)
 {
-    seqan3::test::tmp_filename filename{"sequence_file_output_test.fasta.gz"};
+    seqan3::test::tmp_directory tmp;
+    auto filename = tmp.path() / "sequence_file_output_test.fasta.gz";
 
     {
-        std::ofstream of{filename.get_path(), std::ios::binary};
+        std::ofstream of{filename, std::ios::binary};
 
         std::copy(begin(input_gz), end(input_gz), std::ostreambuf_iterator<char>{of});
     }
 
-    seqan3::sequence_file_input fin{filename.get_path()};
+    seqan3::sequence_file_input fin{filename};
 
     decompression_impl(*this, fin);
 }
@@ -362,29 +370,31 @@ std::string input_bgzf{'\x1F', '\x8B', '\x08', '\x04', '\x00', '\x00', '\x00', '
 
 TEST_F(sequence_file_input_f, bgzf_decompression_by_filename_bgzf)
 {
-    seqan3::test::tmp_filename filename{"sequence_file_output_test.fasta.bgzf"};
+    seqan3::test::tmp_directory tmp;
+    auto filename = tmp.path() / "sequence_file_output_test.fasta.bgzf";
 
     {
-        std::ofstream of{filename.get_path(), std::ios::binary};
+        std::ofstream of{filename, std::ios::binary};
 
         std::copy(input_bgzf.begin(), input_bgzf.end(), std::ostreambuf_iterator<char>{of});
     }
 
-    seqan3::sequence_file_input fin{filename.get_path()};
+    seqan3::sequence_file_input fin{filename};
 
     decompression_impl(*this, fin);
 }
 
 TEST_F(sequence_file_input_f, bgzf_decompression_by_filename_gz)
 {
-    seqan3::test::tmp_filename filename{"sequence_file_output_test.fasta.gz"};
+    seqan3::test::tmp_directory tmp;
+    auto filename = tmp.path() / "sequence_file_output_test.fasta.gz";
 
     {
-        std::ofstream of{filename.get_path(), std::ios::binary};
+        std::ofstream of{filename, std::ios::binary};
         std::copy(input_bgzf.begin(), input_bgzf.end(), std::ostreambuf_iterator<char>{of});
     }
 
-    seqan3::sequence_file_input fin{filename.get_path()};
+    seqan3::sequence_file_input fin{filename};
     decompression_impl(*this, fin);
 }
 
@@ -418,15 +428,16 @@ std::string input_bz2{'\x42', '\x5A', '\x68', '\x39', '\x31', '\x41', '\x59', '\
 
 TEST_F(sequence_file_input_f, decompression_by_filename_bz2)
 {
-    seqan3::test::tmp_filename filename{"sequence_file_output_test.fasta.bz2"};
+    seqan3::test::tmp_directory tmp;
+    auto filename = tmp.path() / "sequence_file_output_test.fasta.bz2";
 
     {
-        std::ofstream of{filename.get_path(), std::ios::binary};
+        std::ofstream of{filename, std::ios::binary};
 
         std::copy(begin(input_bz2), end(input_bz2), std::ostreambuf_iterator<char>{of});
     }
 
-    seqan3::sequence_file_input fin{filename.get_path()};
+    seqan3::sequence_file_input fin{filename};
 
     decompression_impl(*this, fin);
 }
