@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -18,7 +18,7 @@
 #include <seqan3/io/views/detail/istreambuf_view.hpp>
 #include <seqan3/io/views/detail/take_until_view.hpp>
 #include <seqan3/test/expect_range_eq.hpp>
-#include <seqan3/test/tmp_filename.hpp>
+#include <seqan3/test/tmp_directory.hpp>
 #include <seqan3/utility/char_operations/predicate.hpp>
 
 #include "../../../range/iterator_test_template.hpp"
@@ -91,15 +91,16 @@ TEST(view_istreambuf, big_file_stram)
 {
     using namespace std::literals;
 
-    seqan3::test::tmp_filename file_name{"istream_storage"};
+    seqan3::test::tmp_directory tmp_dir{};
+    auto file_name = tmp_dir.path() / "istream_storage";
 
     {
-        std::ofstream os{file_name.get_path()};
+        std::ofstream os{file_name};
         for (size_t idx = 0; idx < 11000; ++idx)
             os << "halloballo\n";
     }
 
-    std::ifstream istream{file_name.get_path()};
+    std::ifstream istream{file_name};
     auto v = seqan3::detail::istreambuf(istream);
     while (v.begin() != v.end())
     {
