@@ -1,14 +1,11 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2021, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2021, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
 
 #include <gtest/gtest.h>
-#include <optional>
-#include <ostream>
-#include <variant>
 
 #include <seqan3/alphabet/detail/debug_stream_alphabet.hpp>
 #include <seqan3/alphabet/nucleotide/dna4.hpp>
@@ -22,6 +19,7 @@ using seqan3::operator""_dna4;
 using namespace std::string_literals;
 
 // Returns a string as gtest would print the given value.
+// Output might change due to changes in gtest.
 auto gtest_str = [](auto && v)
 {
     return ::testing::PrintToString(v);
@@ -36,78 +34,68 @@ auto debug_str = [](auto && v)
     return sstream.str();
 };
 
-TEST(pretty_printing, gtest_output)
+TEST(pretty_printing, char)
 {
-    // warning: these outputs can change due to changes in gtest
     EXPECT_EQ(gtest_str('a'), "'a' (97, 0x61)"s);
     EXPECT_EQ(debug_str('a'), "a"s);
-
-    EXPECT_EQ(gtest_str(std::make_tuple<int, int>(42, -10)), "(42, -10)"s);
-    EXPECT_EQ(debug_str(std::make_tuple<int, int>(42, -10)), "(42,-10)"s);
-
-#if GTEST_INTERNAL_HAS_VARIANT // googletest at head (>=1.10.x)
-    EXPECT_EQ(gtest_str(std::variant<int>{0}), "('int(index = 0)' with value 0)"s);
-#else // googletest <= 1.10.0
-    EXPECT_EQ(gtest_str(std::variant<int>{0}), "0"s);
-#endif
-    EXPECT_EQ(debug_str(std::variant<int>{0}), "0"s);
-
-#if GTEST_INTERNAL_HAS_OPTIONAL // googletest at head (>=1.10.x)
-    EXPECT_EQ(gtest_str(std::optional<int>{}), "(nullopt)"s);
-#else // googletest <= 1.10.0
-    EXPECT_EQ(gtest_str(std::optional<int>{}), "<VALUELESS_OPTIONAL>"s);
-#endif
-    EXPECT_EQ(debug_str(std::optional<int>{}), "<VALUELESS_OPTIONAL>"s);
 }
 
-TEST(pretty_printing, std_output)
+TEST(pretty_printing, tuple)
 {
-    // if any of these tests get supported by googletest move them to gtest_output
-    EXPECT_EQ(gtest_str(std::vector<std::vector<int>>{{0,1}, {2,3}, {1,2}, {0}}), "[[0,1],[2,3],[1,2],[0]]"s);
-    EXPECT_EQ(debug_str(std::vector<std::vector<int>>{{0,1}, {2,3}, {1,2}, {0}}), "[[0,1],[2,3],[1,2],[0]]"s);
+    EXPECT_EQ(gtest_str(std::make_tuple<int, int>(42, -10)), "(42, -10)"s);
+    EXPECT_EQ(debug_str(std::make_tuple<int, int>(42, -10)), "(42,-10)"s);
+}
 
-    EXPECT_EQ(gtest_str(std::nullopt), "<VALUELESS_OPTIONAL>"s);
+TEST(pretty_printing, variant)
+{
+    EXPECT_EQ(gtest_str(std::variant<int>{0}), "('int(index = 0)' with value 0)"s);
+    EXPECT_EQ(debug_str(std::variant<int>{0}), "0"s);
+}
+
+TEST(pretty_printing, optional)
+{
+    EXPECT_EQ(gtest_str(std::optional<int>{}), "(nullopt)"s);
+    EXPECT_EQ(debug_str(std::optional<int>{}), "<VALUELESS_OPTIONAL>"s);
+
+    EXPECT_EQ(gtest_str(std::nullopt), "(nullopt)"s);
     EXPECT_EQ(debug_str(std::nullopt), "<VALUELESS_OPTIONAL>"s);
 }
 
-TEST(pretty_printing, seqan3_output)
+TEST(pretty_printing, vector)
 {
-    // seqan3 types should always produce the same result
-    EXPECT_EQ(gtest_str('G'_dna4), "G"s);
-    EXPECT_EQ(debug_str('G'_dna4), "G"s);
-    EXPECT_EQ('G'_dna4, 'G'_dna4); // change value to test
-
-    EXPECT_EQ(gtest_str("ACGTCGA"_dna4), "ACGTCGA"s);
-    EXPECT_EQ(debug_str("ACGTCGA"_dna4), "ACGTCGA"s);
-    EXPECT_EQ("ACGTCGA"_dna4, "ACGTCGA"_dna4); // change value to test
-
-    std::vector dna_set1{"AC"_dna4, "GT"_dna4, "CG"_dna4, "A"_dna4};
-    std::vector dna_set2{"AC"_dna4, "GT"_dna4, "CG"_dna4, "A"_dna4};
-    EXPECT_EQ(gtest_str(dna_set1), "[AC,GT,CG,A]"s);
-    EXPECT_EQ(debug_str(dna_set1), "[AC,GT,CG,A]"s);
-    EXPECT_EQ(dna_set1, dna_set2); // change value to test
-
-    std::vector dna_sets1{std::vector{"AC"_dna4, "GT"_dna4}, std::vector{"CG"_dna4, "A"_dna4}};
-    std::vector dna_sets2{std::vector{"AC"_dna4, "GT"_dna4}, std::vector{"CG"_dna4, "A"_dna4}};
-    EXPECT_EQ(gtest_str(dna_sets1), "[[AC,GT],[CG,A]]"s);
-    EXPECT_EQ(debug_str(dna_sets1), "[[AC,GT],[CG,A]]"s);
-    EXPECT_EQ(dna_sets1, dna_sets2); // change value to test
+    EXPECT_EQ(gtest_str(std::vector<std::vector<int>>{{0, 1}, {2, 3}, {1, 2}, {0}}), "[[0,1],[2,3],[1,2],[0]]"s);
+    EXPECT_EQ(debug_str(std::vector<std::vector<int>>{{0, 1}, {2, 3}, {1, 2}, {0}}), "[[0,1],[2,3],[1,2],[0]]"s);
 }
 
-TEST(pretty_printing, gtest_mixed_seqan3_output)
+TEST(pretty_printing, dna)
 {
-    // warning: these outputs can change due to changes in gtest
-    auto dna_tuple1 = std::make_tuple('A'_dna4, 'C'_dna4);
-    auto dna_tuple2 = std::make_tuple('A'_dna4, 'C'_dna4);
-    EXPECT_EQ(gtest_str(dna_tuple1), "(A, C)"s);
-    EXPECT_EQ(debug_str(dna_tuple1), "(A,C)"s);
-    EXPECT_EQ(dna_tuple1, dna_tuple2); // change value to test
+    EXPECT_EQ(gtest_str('G'_dna4), "G"s);
+    EXPECT_EQ(debug_str('G'_dna4), "G"s);
+}
 
-    auto dna_sequence_tuple1 = std::make_tuple("AC"_dna4, "GT"_dna4);
-    auto dna_sequence_tuple2 = std::make_tuple("AC"_dna4, "GT"_dna4);
-    EXPECT_EQ(gtest_str(dna_sequence_tuple1), "(AC, GT)"s);
-    EXPECT_EQ(debug_str(dna_sequence_tuple1), "(AC,GT)"s);
-    EXPECT_EQ(dna_sequence_tuple1, dna_sequence_tuple2); // change value to test
+TEST(pretty_printing, dna_sequence)
+{
+    EXPECT_EQ(gtest_str("ACGTCGA"_dna4), "ACGTCGA"s);
+    EXPECT_EQ(debug_str("ACGTCGA"_dna4), "ACGTCGA"s);
+
+    std::vector dna_2d{"AC"_dna4, "GT"_dna4, "CG"_dna4, "A"_dna4};
+    EXPECT_EQ(gtest_str(dna_2d), "[AC,GT,CG,A]"s);
+    EXPECT_EQ(debug_str(dna_2d), "[AC,GT,CG,A]"s);
+
+    std::vector dna_3d{std::vector{"AC"_dna4, "GT"_dna4}, std::vector{"CG"_dna4, "A"_dna4}};
+    EXPECT_EQ(gtest_str(dna_3d), "[[AC,GT],[CG,A]]"s);
+    EXPECT_EQ(debug_str(dna_3d), "[[AC,GT],[CG,A]]"s);
+}
+
+TEST(pretty_printing, dna_tuple)
+{
+    auto dna_tuple = std::make_tuple('A'_dna4, 'C'_dna4);
+    EXPECT_EQ(gtest_str(dna_tuple), "(A, C)"s);
+    EXPECT_EQ(debug_str(dna_tuple), "(A,C)"s);
+
+    auto dna_sequence_tuple = std::make_tuple("AC"_dna4, "GT"_dna4);
+    EXPECT_EQ(gtest_str(dna_sequence_tuple), "(AC, GT)"s);
+    EXPECT_EQ(debug_str(dna_sequence_tuple), "(AC,GT)"s);
 }
 
 namespace seqan3::detail
@@ -143,12 +131,11 @@ inline debug_stream_type<char_t> & operator<<(debug_stream_type<char_t> & s, my_
 
 } // namespace seqan3
 
-TEST(pretty_printing, seqan3_detail_output)
+TEST(pretty_printing, seqan3_detail)
 {
     // seqan3 types should always produce the same result
     EXPECT_EQ(gtest_str(seqan3::detail::my_type{"HALLO"s}), "HALLO"s);
     EXPECT_EQ(debug_str(seqan3::detail::my_type{"HALLO"s}), "HALLO"s);
-    EXPECT_EQ(seqan3::detail::my_type{"HALLO"}, seqan3::detail::my_type{"HALLO"}); // change value to test
 }
 
 namespace seqan3
@@ -167,10 +154,9 @@ inline debug_stream_type<char_t> & operator<<(debug_stream_type<char_t> & s, you
 
 } // namespace seqan3
 
-TEST(pretty_printing, seqan3_detail_mixed_seqan3_output)
+TEST(pretty_printing, seqan3_detail_inherit)
 {
     // seqan3 types should always produce the same result
     EXPECT_EQ(gtest_str(seqan3::your_type{"HALLO"s}), "HALLO"s);
     EXPECT_EQ(debug_str(seqan3::your_type{"HALLO"s}), "HALLO"s);
-    EXPECT_EQ(seqan3::your_type{"HALLO"}, seqan3::your_type{"HALLO"}); // change value to test
 }
