@@ -1,6 +1,6 @@
 // -----------------------------------------------------------------------------------------------------
-// Copyright (c) 2006-2022, Knut Reinert & Freie Universität Berlin
-// Copyright (c) 2016-2022, Knut Reinert & MPI für molekulare Genetik
+// Copyright (c) 2006-2023, Knut Reinert & Freie Universität Berlin
+// Copyright (c) 2016-2023, Knut Reinert & MPI für molekulare Genetik
 // This file may be used, modified and/or redistributed under the terms of the 3-clause BSD-License
 // shipped with this file and also available at: https://github.com/seqan/seqan3/blob/master/LICENSE.md
 // -----------------------------------------------------------------------------------------------------
@@ -11,7 +11,7 @@
 #include <type_traits>
 #include <vector>
 
-#include <seqan3/core/detail/persist_view.hpp>
+#include <seqan3/core/detail/all_view.hpp>
 #include <seqan3/test/expect_same_type.hpp>
 #include <seqan3/utility/views/single_pass_input.hpp>
 
@@ -54,7 +54,6 @@ public:
 // add all <out_rng,in_rng> pairs here.
 using underlying_range_types = ::testing::Types<std::vector<char>,
                                                 std::vector<int>,
-                                                std::vector<char> const,
                                                 std::ranges::basic_istream_view<char, char, std::char_traits<char>>,
                                                 std::ranges::basic_istream_view<int, char, std::char_traits<char>>>;
 
@@ -62,8 +61,7 @@ TYPED_TEST_SUITE(single_pass_input, underlying_range_types, );
 
 TYPED_TEST(single_pass_input, view_concept)
 {
-    using rng_t = decltype(std::declval<TypeParam &>() | std::views::all);
-    using view_t = seqan3::detail::single_pass_input_view<rng_t>;
+    using view_t = seqan3::detail::single_pass_input_view<seqan3::detail::all_t<TypeParam &>>;
     EXPECT_TRUE((std::derived_from<view_t, std::ranges::view_interface<view_t>>));
     EXPECT_TRUE((std::sentinel_for<std::ranges::sentinel_t<view_t>, std::ranges::iterator_t<view_t>>));
     EXPECT_TRUE(std::ranges::range<view_t>);
@@ -117,8 +115,7 @@ TYPED_TEST(single_pass_input, deduction_guide_view)
 
 TYPED_TEST(single_pass_input, view_construction)
 {
-    using rng_t = decltype(std::declval<TypeParam>() | seqan3::detail::persist);
-    using view_t = seqan3::detail::single_pass_input_view<rng_t>;
+    using view_t = seqan3::detail::single_pass_input_view<seqan3::detail::all_t<TypeParam>>;
     EXPECT_TRUE(std::is_default_constructible_v<view_t>);
     EXPECT_TRUE(std::is_copy_constructible_v<view_t>);
     EXPECT_TRUE(std::is_move_constructible_v<view_t>);
@@ -132,7 +129,7 @@ TYPED_TEST(single_pass_input, view_construction)
     }
 
     { // from view
-        [[maybe_unused]] seqan3::detail::single_pass_input_view v{TypeParam{this->data} | seqan3::detail::persist};
+        [[maybe_unused]] seqan3::detail::single_pass_input_view v{TypeParam{this->data} | seqan3::detail::all};
     }
 }
 
@@ -183,16 +180,14 @@ TYPED_TEST(single_pass_input, view_iterate)
 
 TYPED_TEST(single_pass_input, iterator_concepts)
 {
-    using view_type =
-        seqan3::detail::single_pass_input_view<decltype(std::declval<TypeParam>() | seqan3::detail::persist)>;
+    using view_type = seqan3::detail::single_pass_input_view<seqan3::detail::all_t<TypeParam>>;
     EXPECT_TRUE((std::input_iterator<std::ranges::iterator_t<view_type>>));
     EXPECT_FALSE((std::forward_iterator<std::ranges::iterator_t<view_type>>));
 }
 
 TYPED_TEST(single_pass_input, iterator_construction)
 {
-    using view_type =
-        seqan3::detail::single_pass_input_view<decltype(std::declval<TypeParam>() | seqan3::detail::persist)>;
+    using view_type = seqan3::detail::single_pass_input_view<seqan3::detail::all_t<TypeParam>>;
     using iterator_type = std::ranges::iterator_t<view_type>;
     EXPECT_TRUE(std::is_default_constructible_v<iterator_type>);
     EXPECT_TRUE(std::is_copy_constructible_v<iterator_type>);
@@ -297,8 +292,7 @@ TYPED_TEST(single_pass_input, iterator_neq_comparison)
 
 TYPED_TEST(single_pass_input, sentinel_concepts)
 {
-    using view_type =
-        seqan3::detail::single_pass_input_view<decltype(std::declval<TypeParam>() | seqan3::detail::persist)>;
+    using view_type = seqan3::detail::single_pass_input_view<seqan3::detail::all_t<TypeParam>>;
     using iterator_type = std::ranges::iterator_t<view_type>;
     using sentinel_type = std::ranges::sentinel_t<view_type>;
 
